OC.L10N.register(
    "spreed",
    {
    "a conversation" : "uma conversa",
    "(Duration %s)" : "(Duração %s)",
    "You attended a call with {user1}" : "Você atendeu uma chamada com {user1}",
    "_%n guest_::_%n guests_" : ["%n convidado","%n convidados","%n convidados"],
    "You attended a call with {user1} and {user2}" : "Você atendeu uma chamada com {user1} e {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Você atendeu uma chamada com {user1}, {user2} e {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Você atendeu uma chamada com {user1}, {user2}, {user3} e {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Você atendeu uma chamada com {user1}, {user2}, {user3}, {user4} e {user5}",
    "_%n other_::_%n others_" : ["%n outro","%n outros","%n outros"],
    "{actor} invited you to {call}" : "{actor} convidou você para {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Você foi convidado para uma <strong>conversa</strong> ou recebeu uma <strong>chamada</strong>",
    "Other activities" : "Outras atividades",
    "Talk" : "Talk",
    "Guest" : "Convidado",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## Bem-vindo ao Nextcloud Talk!\nNesta conversa você será informado sobre as novidades disponíveis no Nextcloud Talk.",
    "## New in Talk %s" : "## Novo no Talk %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Agora o Microsoft Edge e o Safari podem ser usados para participar de chamadas de áudio e vídeo",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- As conversas individuais agora são persistentes e não podem mais ser transformadas em conversas em grupo por acidente. Além disso, quando um dos participantes sai da conversa, a conversa não é mais excluída automaticamente. Somente se ambos os participantes saírem, a conversa será excluída do servidor",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Agora você pode notificar todos os participantes postando \"@all\" no chat",
    "- With the \"arrow-up\" key you can repost your last message" : "- Com a tecla \"seta para cima\" você pode repostar sua última mensagem",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Agora o Talk pode ter comandos, envie \"/help\" como uma mensagem de chat para ver se o seu administrador configurou algum",
    "- With projects you can create quick links between conversations, files and other items" : "- Com projetos você pode criar links rápidos entre conversas, arquivos e outros itens",
    "- You can now mention guests in the chat" : "- Agora você pode mencionar convidados no chat",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- As conversas agora podem ter uma sala de espera. Isso permitirá que os moderadores já entrem no bate-papo e chamada para preparar a reunião, enquanto os usuários e convidados terão que esperar",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Agora você pode responder diretamente a mensagens, dando aos outros usuários mais contexto sobre o que é sua mensagem",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- A pesquisa de conversas e participantes agora também filtrará as conversas existentes, facilitando a localização de conversas anteriores.",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Agora você pode adicionar grupos de usuários personalizados a conversas quando o aplicativo de círculos estiver instalado",
    "- Check out the new grid and call view" : "- Confira a nova grade e visualização de chamadas",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Agora você pode enviar e arrastar arquivos diretamente do seu dispositivo para o chat",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Os arquivos compartilhados agora são abertos diretamente dentro da visualização de bate-papo com aplicativos visualizadores",
    "- You can now search for chats and messages in the unified search in the top bar" : "- Você pode buscar conversas e mensagens usando a pesquisa unificada na barra superior",
    "- Spice up your messages with emojis from the emoji picker" : "- Anime suas mensagens com emojis do seletor de emojis",
    "- You can now change your camera and microphone while being in a call" : "- Você pode mudar a câmera e o microfone enquanto está em uma chamada",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- Dê às suas conversas algum contexto com uma descrição e abra-as para que os usuários conectados possam encontrá-las e juntar-se a elas ",
    "- See a read status and send failed messages again" : "- Ver um status de leitura e enviar novamente as mensagens com falha",
    "- Raise your hand in a call with the R key" : "- Levante a mão com a tecla R durante uma chamada",
    "- Join the same conversation and call from multiple devices" : "- Entre na mesma conversa e ligue de vários dispositivos ",
    "- Send voice messages, share your location or contact details" : "- Envie mensagens de voz, compartilhe sua localização ou detalhes de contato ",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Adicione grupos a uma conversa e novos membros do grupo serão automaticamente adicionados como participantes ",
    "- A preview of your audio and video is shown before joining a call" : "- Uma pré-visualização de seu áudio e vídeo é mostrada antes de entrar em uma chamada",
    "- You can now blur your background in the newly designed call view" : "- Agora você pode desfocar seu plano de fundo na visualização de chamada recém-redesenhada",
    "- Moderators can now assign general and individual permissions to participants" : "- Os moderadores agora podem atribuir permissões gerais e individuais aos participantes",
    "- You can now react to chat messages" : "- Agora você pode reagir às mensagens do chat",
    "- In the sidebar you can now find an overview of the latest shared items" : "- Na barra lateral, agora você pode encontrar uma visão geral dos últimos itens compartilhados",
    "- Use a poll to collect the opinions of others or settle on a date" : "- Use uma enquete para coletar as opiniões de outras pessoas ou estabelecer uma data",
    "- Configure an expiration time for chat messages" : "- Configure um tempo de expiração para mensagens de bate-papo",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- Inicie chamadas sem notificar outras pessoas em grandes conversas. Você pode enviar notificações de chamadas individuais assim que a chamada for iniciada.",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- Envie mensagens de bate-papo sem notificar os destinatários caso não seja urgente",
    "- Emojis can now be autocompleted by typing a \":\"" : "- Emojis agora podem ser preenchidos automaticamente digitando um \":\"",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- Vincule vários itens usando o novo seletor inteligente digitando um \"/\"",
    "- Moderators can now create breakout rooms (requires the High-performance backend)" : "- Os moderadores agora podem criar salas temáticas (requer o back-end de alto desempenho)",
    "- Calls can now be recorded (requires the High-performance backend)" : "- As chamadas agora podem ser gravadas (requer o back-end de alto desempenho)",
    "- Conversations can now have an avatar or emoji as icon" : "- Conversas agora podem ter um avatar ou um emoji como ícone",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- Planos de fundo virtuais agora estão disponível além do plano de fundo desfocado nas chamadas de vídeo",
    "- Reactions are now available during calls" : "- Reações agora estão disponíveis durante chamadas",
    "- Typing indicators show which users are currently typing a message" : "- Os indicadores de digitação mostram quais usuários estão digitando uma mensagem no momento",
    "- Groups can now be mentioned in chats" : "- Grupos agora podem ser mencionados em bate-papos",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "- As gravações de conferências são transcritas automaticamente se um aplicativo que faz transcrições estiver disponível",
    "- Chat messages can be translated if a translation provider app is registered" : "- Mensagens de chat podem ser traduzidas se um provedor de traduções estiver disponível",
    "- **Markdown** can now be used in _chat_ messages" : "- **Markdown** agora pode ser usado em mensagens de _bate-papo_",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "- Webhooks agora estão disponíveis para implementar bots. Consulte a documentação para obter mais informações https://nextcloud-talk.readthedocs.io/en/latest/bot-list/",
    "- Set a reminder on a chat message to be notified later again" : "- Defina um lembrete em uma mensagem de bate-papo para ser notificado novamente mais tarde",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- Use a conversa **Nota para si mesmo** para fazer anotações e compartilhar informações entre seus dispositivos",
    "- Captions allow to send a message with a file at the same time" : "- As legendas permitem enviar uma mensagem com um arquivo ao mesmo tempo",
    "- Video of the speaker is now visible while sharing the screen and call reactions are animated" : "- O vídeo do orador agora está visível ao compartilhar a tela e as reações da chamada são animadas",
    "- Messages can now be edited by logged-in authors and moderators for 6 hours" : "- As mensagens agora podem ser editadas por autores e moderadores logados por 6 horas",
    "- Unsent message drafts are now saved in your browser" : "- Rascunhos de mensagens não enviadas agora são salvos em seu navegador",
    "- Text chatting can now be done in a federated way with other Talk servers" : "- O bate-papo por texto agora pode ser feito de forma federada com outros servidores Talk",
    "- Moderators can now ban accounts and guests to prevent them from rejoining a conversation" : "- Os moderadores agora podem banir contas e convidados para impedir que eles voltem a participar de uma conversa",
    "- Upcoming calls from linked calendar events and out-of-office replacements are now shown in conversations" : "- As próximas chamadas de eventos de calendário vinculados e os substitutos de ausência do escritório agora são exibidos nas conversas",
    "- Calls can now be done in a federated way with other Talk servers (requires the High-performance backend)" : "- As chamadas agora podem ser feitas de forma federada com outros servidores Talk (requer o back-end de alto desempenho)",
    "- Introducing the Nextcloud Talk desktop client for Windows, macOS and Linux: %s" : "- Apresentando o cliente de desktop Nextcloud Talk para Windows, macOS e Linux: %s",
    "- Summarize call recordings and unread messages in chats with the Nextcloud Assistant" : "- Resuma gravações de chamadas e mensagens não lidas em bate-papos com o Assistente Nextcloud",
    "- Improved meetings with recognizing guests invited via their email address, import of participant lists, drafts for polls and downloading call participant lists" : "- Reuniões aprimoradas com reconhecimento de convidados por meio de seus endereços de e-mail, importação de listas de participantes, rascunhos para enquetes e download de listas de participantes de chamadas",
    "- Archive conversations to stay focused" : "- Arquive conversas para manter o foco",
    "- Schedule a meeting into your calendar from within a conversation" : "- Agende uma reunião em seu calendário a partir de uma conversa",
    "- Search for messages of the current conversation directly in the right sidebar" : "- Pesquise mensagens da conversa atual diretamente na barra lateral direita",
    "- See more conversations on a first glance with the new compact list (enable in the Talk settings)" : "- Veja mais conversas em uma primeira olhada com a nova lista compacta (ative nas configurações do Talk)",
    "- Meeting conversations now sync the title and description from the calendar and are hidden with a search filter until they are close to the start" : "- As conversas de reunião agora sincronizam o título e a descrição do calendário e ficam ocultas com um filtro de pesquisa até que estejam próximas do início",
    "- Mark conversations as sensitive in the notification settings, to hide the message content from the conversation list and notifications" : "- Marque as conversas como confidenciais nas configurações de notificação para ocultar o conteúdo da mensagem da lista de conversas e das notificações",
    "- To receive push notifications during \"Do not disturb\", mark conversations as important" : "- Para receber notificações push durante o \"Não perturbe\", marque as conversas como importantes",
    "- Add other participants to a one-to-one call to create a new group call on the fly" : "- Adicione outros participantes a uma chamada individual para criar uma nova chamada em grupo em tempo real",
    "- Use threads to keep your chat and discussions organized" : "- Use fios para manter suas conversas e discussões organizadas",
    "- Live transcriptions now available during the call (requires the live-transcription ExApp and the High-performance backend)" : "- Transcrições em tempo real agora disponíveis durante a chamada (requer o ExApp de transcrição em tempo real e o back-end de alto desempenho)",
    "- Moderators can now pin messages so they are kept at the top" : "- Os moderadores agora podem fixar mensagens para que elas permaneçam no topo",
    "- Schedule a message to send it at a later time" : "- Agende uma mensagem para enviá-la mais tarde",
    "_All %n participant_::_All %n participants_" : ["Todos os %n participantes","Todos os %n participantes","Todos os %n participantes"],
    "Talk updates ✅" : "Atualizações do Talk ✅",
    "Reaction deleted by author" : "Reação excluída pelo autor",
    "{actor} created the conversation" : "{actor} criou a conversa",
    "You created the conversation" : "Você criou a conversa",
    "System created the conversation" : "O sistema criou a conversa",
    "An administrator created the conversation" : "Um administrador criou a conversa",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} renomeou a conversa de \"%1$s\" para \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Você renomeou a conversa de \"%1$s\" para \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Um administrador renomeou a conversa \"%1$s\" para \"%2$s\"",
    "{actor} set the description" : "{actor} definiu a descrição",
    "You set the description" : "Você definiu a descrição",
    "An administrator set the description" : "Um administrador definiu a descrição",
    "{actor} removed the description" : "{actor} removeu a descrição",
    "You removed the description" : "Você removeu a descrição",
    "An administrator removed the description" : "Um administrador removeu a descrição",
    "You started a silent call" : "Você iniciou uma chamada silenciosa",
    "Outgoing silent call" : "Chamada silenciosa de saída",
    "{actor} started a silent call" : "{actor} iniciou uma chamada silenciosa",
    "Incoming silent call" : "Chamada silenciosa recebida",
    "You started a call" : "Você iniciou uma chamada",
    "Outgoing call" : "Chamada de saída",
    "{actor} started a call" : "{actor} iniciou uma chamada",
    "Incoming call" : "Chamada recebida",
    "{actor} joined the call" : "{actor} entrou na chamada",
    "You joined the call" : "Você entrou na chamada",
    "{actor} left the call" : "{actor} saiu da chamada",
    "You left the call" : "Você saiu da chamada",
    "{actor} unlocked the conversation" : "{actor} destrancou a conversa",
    "You unlocked the conversation" : "Você destrancou a conversa",
    "An administrator unlocked the conversation" : "Um administrador destrancou a conversa",
    "{actor} locked the conversation" : "{actor} trancou a conversa",
    "You locked the conversation" : "Você trancou a conversa",
    "An administrator locked the conversation" : "Um administrador trancou a conversa",
    "{actor} limited the conversation to the current participants" : "{actor} limitou a conversa aos atuais participantes",
    "You limited the conversation to the current participants" : "Você limitou a conversa aos atuais participantes",
    "An administrator limited the conversation to the current participants" : "Um administrador limitou a conversa aos atuais participantes",
    "{actor} opened the conversation to registered users" : "{actor} abriu a conversa aos usuários registrados",
    "You opened the conversation to registered users" : "Você abriu a conversa aos usuários registrados",
    "An administrator opened the conversation to registered users" : "Um administrador abriu a conversa aos usuários registrados",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "{actor} abriu a conversa para usuários registrados e usuários criados com o aplicativo Convidados",
    "You opened the conversation to registered users and users created with the Guests app" : "Você abriu a conversa para usuários registrados e usuários criados com o aplicativo Convidados",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "Um administrador abriu a conversa para usuários registrados e usuários criados com o aplicativo Convidados",
    "The conversation is now open to everyone" : "A conversa está aberta a todos agora",
    "{actor} opened the conversation to everyone" : "{actor} abriu a conversa a todos",
    "You opened the conversation to everyone" : "Você abriu a conversa para todos",
    "{actor} restricted the conversation to moderators" : "{actor} restringiu a conversa aos moderadores",
    "You restricted the conversation to moderators" : "Você restringiu a conversa aos moderadores",
    "{actor} started breakout rooms" : "{actor} iniciou salas temáticas",
    "You started breakout rooms" : "Você iniciou salas temáticas",
    "{actor} stopped breakout rooms" : "{actor} interrompeu as salas temáticas",
    "You stopped breakout rooms" : "Você interrompeu as salas temáticas",
    "{actor} allowed guests" : "{actor} permitiu convidados",
    "You allowed guests" : "Você permitiu convidados",
    "An administrator allowed guests" : "Um administrador autorizou convidados",
    "{actor} disallowed guests" : "{actor} bloqueou convidados",
    "You disallowed guests" : "Você bloqueou convidados",
    "An administrator disallowed guests" : "Um administrador desautorizou convidados",
    "{actor} set a password" : "{actor} definiu uma senha",
    "You set a password" : "Você definiu uma senha",
    "An administrator set a password" : "Um administrador definiu uma senha",
    "{actor} removed the password" : "{actor} removeu a senha",
    "You removed the password" : "Você removeu a senha",
    "An administrator removed the password" : "Um administrador removeu a senha",
    "{actor} added {user}" : "{actor} adicionou {user}",
    "You joined the conversation" : "Você juntou-se à conversa",
    "{actor} joined the conversation" : "{actor} juntou-se à conversa",
    "You added {user}" : "Você adicionou {user}",
    "{actor} added you" : "{actor} adicionou você",
    "An administrator added you" : "Um administrador adicionou você",
    "An administrator added {user}" : "Um administrador adicionou {user}",
    "You left the conversation" : "Você saiu da conversa",
    "{actor} left the conversation" : "{actor} saiu da conversa",
    "{actor} removed {user}" : "{actor} removeu {user}",
    "You removed {user}" : "Você removeu {user}",
    "{actor} removed you" : "{actor} removeu você",
    "An administrator removed you" : "Um administrador excluiu você",
    "An administrator removed {user}" : "Um administrador removeu {user}",
    "{actor} invited {federated_user}" : "{actor} convidou {federated_user}",
    "You invited {federated_user}" : "Você convidou {federated_user}",
    "You accepted the invitation" : "Você aceitou o convite",
    "{actor} invited you" : "{actor} convidou você",
    "An administrator invited you" : "Um administrador convidou você",
    "An administrator invited {federated_user}" : "Um administrador convidou {federated_user}",
    "{federated_user} accepted the invitation" : "{federated_user} aceitou o convite",
    "{actor} removed {federated_user}" : "{actor} removeu {federated_user}",
    "You removed {federated_user}" : "Você removeu {federated_user}",
    "You declined the invitation" : "Você recusou o convite",
    "An administrator removed {federated_user}" : "Um administrador removeu {federated_user}",
    "{federated_user} declined the invitation" : "{federated_user} recusou o convite",
    "{actor} added group {group}" : "{actor} adiciniou o grupo  {group}",
    "You added group {group}" : "Você adicionou o grupo  {group}",
    "An administrator added group {group}" : "Um administrador adicionou o grupo  {group}",
    "{actor} removed group {group}" : "{actor} removeu o grupo  {group}",
    "You removed group {group}" : "Você removeu o grupo  {group}",
    "An administrator removed group {group}" : "Um administrador removeu o grupo {group}",
    "{actor} added team {circle}" : "{actor} adicionou a equipe {circle}",
    "You added team {circle}" : "Você adicionou a equipe {circle}",
    "An administrator added team {circle}" : "Um administrador adicionou a equipe {circle}",
    "{actor} removed team {circle}" : "{actor} removeu a equipe {circle}",
    "You removed team {circle}" : "Você removeu a equipe {circle}",
    "An administrator removed team {circle}" : "Um administrador removeu a equipe {circle}",
    "{actor} added {phone}" : "{actor} adicionou {phone}",
    "You added {phone}" : "Você adicionou {phone}",
    "An administrator added {phone}" : "Um administrador adicionou {phone}",
    "{actor} removed {phone}" : "{actor} removeu {phone}",
    "You removed {phone}" : "Você removeu {phone}",
    "An administrator removed {phone}" : "Um administrador removeu {phone}",
    "{actor} promoted {user} to moderator" : "{actor} promoveu {user} a moderador",
    "You promoted {user} to moderator" : "Você promoveu {user} a moderador",
    "{actor} promoted you to moderator" : "{actor} promoveu você a moderador",
    "An administrator promoted you to moderator" : "Um administrador promoveu você a moderador",
    "An administrator promoted {user} to moderator" : "Um administrador promoveu {user} a moderador",
    "{actor} demoted {user} from moderator" : "{actor} removeu {user} da moderação",
    "You demoted {user} from moderator" : "Você removeu {user} da moderação",
    "{actor} demoted you from moderator" : "{actor} removeu você da moderação",
    "An administrator demoted you from moderator" : "Um administrador removeu você da moderação",
    "An administrator demoted {user} from moderator" : "Um administrador removeu {user} da moderação",
    "{actor} shared a file which is no longer available" : "{actor} compartilhou um arquivo não mais disponível",
    "You shared a file which is no longer available" : "Você compartilhou um arquivo não mais disponível",
    "File shares are currently not supported in federated conversations" : "Atualmente, os compartilhamentos de arquivos não são suportados em conversas federadas",
    "The shared location is malformed" : "O local compartilhado está malformado",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} configurou Matterbridge para sincronizar esta conversa com outros bate-papos",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Você configurou Matterbridge para sincronizar esta conversa com outros bate-papos",
    "{actor} created thread {title}" : "{actor} criou o fio {title}",
    "You created thread {title}" : "Você criou o fio {title}",
    "{actor} renamed thread {title}" : "{actor} renomeou o fio {title}",
    "You renamed thread {title}" : "Você renomeou o fio {title}",
    "{actor} updated the Matterbridge configuration" : "{actor} atualizou a configuração Matterbridge",
    "You updated the Matterbridge configuration" : "Você atualizou a configuração Matterbridge",
    "{actor} removed the Matterbridge configuration" : "{actor} removeu a configuração Matterbridge",
    "You removed the Matterbridge configuration" : "Você removeu a configuração Matterbridge",
    "{actor} started Matterbridge" : "{actor} iniciou Matterbridge",
    "You started Matterbridge" : "Você iniciou Matterbridge",
    "{actor} stopped Matterbridge" : "{actor} parou Matterbridge",
    "You stopped Matterbridge" : "Você parou Matterbridge.",
    "{actor} deleted a message" : "{actor} excluiu uma mensagem",
    "You deleted a message" : "Você excluiu uma mensagem",
    "{actor} edited a message" : "{actor} editou uma mensagem",
    "You edited a message" : "Você editou uma mensagem",
    "{actor} pinned a message" : "{actor} fixou uma mensagem",
    "You pinned a message" : "Você fixou uma mensagem",
    "{actor} unpinned a message" : "{actor} desfixou uma mensagem",
    "Message was automatically unpinned" : "A mensagem foi desfixada automaticamente",
    "You unpinned a message" : "Você desfixou uma mensagem",
    "{actor} deleted a reaction" : "{actor} excluiu uma reação",
    "You deleted a reaction" : "Você excluiu uma reação",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["Você definiu a expiração de mensagens para %n semana","Você definiu a expiração de mensagens para %n semanas","Você definiu a expiração de mensagens para %n semanas"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["Você definiu a expiração de mensagens para %n dia","Você definiu a expiração de mensagens para %n dias","Você definiu a expiração de mensagens para %n dias"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["Você definiu a expiração de mensagens para %n hora","Você definiu a expiração de mensagens para %n horas","Você definiu a expiração de mensagens para %n horas"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["Você definiu a expiração de mensagens para %n minuto","Você definiu a expiração de mensagens para %n minutos","Você definiu a expiração de mensagens para %n minutos"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor} definiu a expiração de mensagens para %n semana","{actor} definiu a expiração de mensagens para %n semanas","{actor} definiu a expiração de mensagens para %n semanas"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor} definiu a expiração de mensagens para %n dia","{actor} definiu a expiração de mensagens para %n dias","{actor} definiu a expiração de mensagens para %n dias"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor} definiu a expiração de mensagens para %n hora","{actor} definiu a expiração de mensagens para %n horas","{actor} definiu a expiração de mensagens para %n horas"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor} definiu a expiração de mensagens para %n minuto","{actor} definiu a expiração de mensagens para %n minutos","{actor} definiu a expiração de mensagens para %n minutos"],
    "{actor} disabled message expiration" : "{actor} desativou a expiração de mensagens",
    "You disabled message expiration" : "Você desativou a expiração de mensagens",
    "{actor} cleared the history of the conversation" : "{actor} limpou o histórico da conversa ",
    "You cleared the history of the conversation" : "Você limpou o histórico da conversa ",
    "{actor} set the conversation picture" : "{actor} definiu a imagem da conversa",
    "You set the conversation picture" : "Você definiu a imagem da conversa",
    "{actor} removed the conversation picture" : "{actor} removeu a imagem da conversa",
    "You removed the conversation picture" : "Você removeu a imagem da conversa",
    "{actor} ended the poll {poll}" : "{actor} encerrou a enquete {poll}",
    "You ended the poll {poll}" : "Você encerrou a enquete {poll}",
    "{actor} started the video recording" : "{actor} iniciou a gravação de vídeo",
    "You started the video recording" : "Você iniciou a gravação de vídeo",
    "{actor} stopped the video recording" : "{actor} parou a gravação de vídeo",
    "You stopped the video recording" : "Você parou a gravação de vídeo",
    "{actor} started the audio recording" : "{actor} iniciou a gravação de áudio",
    "You started the audio recording" : "Você iniciou a gravação de áudio",
    "{actor} stopped the audio recording" : "{actor} parou a gravação de áudio",
    "You stopped the audio recording" : "Você parou a gravação de áudio",
    "The recording failed" : "A gravação falhou",
    "Someone voted on the poll {poll}" : "Alguém votou na enquete {poll}",
    "Message deleted by author" : "Mensagem excluída pelo autor",
    "Message deleted by {actor}" : "Mensagem excluída por {actor}",
    "Message deleted by you" : "Mensagem excluída por você",
    "Deleted user" : "Usuário excluído",
    "Unknown number" : "Número desconhecido",
    "Administration" : "Administração",
    "System" : "Sistema",
    "%s (guest)" : "%s (convidado)",
    "Missed call" : "Chamada perdida",
    "Unanswered call" : "Chamada não atendida",
    "Call ended (Duration {duration})" : "Chamada encerrada (Duração {duration})",
    "Call was ended, as it reached the maximum call duration (Duration {duration})" : "A chamada foi encerrada, pois atingiu a duração máxima (Duração {duration})",
    "{actor} ended the call (Duration {duration})" : "{actor} encerrou a chamada (Duração {duration})",
    "_Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})_::_Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})_" : ["A chamada com %n convidado foi encerrada, pois atingiu a duração máxima da chamada (Duração {duration})","A chamada com %n convidados foi encerrada, pois atingiu a duração máxima da chamada (Duração {duration})","A chamada com %n convidados foi encerrada, pois atingiu a duração máxima da chamada (Duração {duration})"],
    "_Call with %n guest ended (Duration {duration})_::_Call with %n guests ended (Duration {duration})_" : ["Chamada com %n convidado encerrada (Duração {duration})","Chamada com %n convidados encerrada (Duração {duration})","Chamada com %n convidados encerrada (Duração {duration})"],
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} encerrou a chamada com %n convidado (Duração {duration})","{actor} encerrou a chamada com %n convidados (Duração {duration})","{actor} encerrou a chamada com %n convidados (Duração {duration})"],
    "Call with {user1} was ended, as it reached the maximum call duration (Duration {duration})" : "A chamada com {user1} foi encerrada, pois atingiu a duração máxima da chamada (Duração {duration})",
    "Call with {user1} ended (Duration {duration})" : "Chamada com {user1} encerrada (Duração {duration})",
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} encerrou a chamada com {user1} (Duração {duration})",
    "Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})" : "A chamada com {user1} e {user2} foi encerrada, pois atingiu a duração máxima da chamada (Duração {duration})",
    "Call with {user1} and {user2} ended (Duration {duration})" : "Chamada com {user1} e {user2} encerrada (Duração {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} encerrou a chamada com {user1} e {user2} (Duração {duration})",
    "Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})" : "A chamada com {user1}, {user2} e {user3} foi encerrada, pois atingiu a duração máxima da chamada (Duração {duration})",
    "Call with {user1}, {user2} and {user3} ended (Duration {duration})" : "Chamada com {user1}, {user2} e {user3} encerrada (Duração {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} encerrou a chamada com {user1}, {user2} e {user3} (Duração {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})" : "A chamada com {user1}, {user2}, {user3} e {user4} foi encerrada, pois atingiu a duração máxima da chamada (Duração {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})" : "Chamada com {user1}, {user2}, {user3} e {user4} encerrada (Duração {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} encerrou a chamada com {user1}, {user2}, {user3} e {user4} (Duração {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})" : "A chamada com {user1}, {user2}, {user3}, {user4} e {user5} foi encerrada, pois atingiu a duração máxima da chamada (Duração {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})" : "Chamada com {user1}, {user2}, {user3}, {user4} e {user5} encerrada (Duração {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} encerrou a chamada com {user1}, {user2}, {user3}, {user4} e {user5} (Duração {duration})",
    "Message of {user} in {conversation}" : "Mensagem de {user} em {conversation}",
    "Message of {user}" : "Mensagem de {user}",
    "Message of a deleted user in {conversation}" : "Mensagem de um usuário excluído em {conversation}",
    "Talk conversations" : "Conversas do Talk",
    "Talk to %s" : "Falar com %s",
    "An error occurred. Please contact your administrator." : "Um erro ocorreu. Entre em contato com seu administrador.",
    "App disabled" : "Aplicativo desativado",
    "Conversation subfolders are disabled" : "As subpastas de conversas estão desativadas",
    "Storage quota exceeded" : "Cota de armazenamento excedida",
    "Could not prepare conversation folder" : "Não foi possível preparar a pasta de conversas",
    "File not found" : "Arquivo não encontrado",
    "Path must point to a file" : "O caminho deve apontar para um arquivo",
    "File is not inside the conversation draft folder for this room" : "O arquivo não está na pasta de rascunhos de conversas desta sala",
    "File is not shared, or shared but not with the user" : "O arquivo não é compartilhado com o usuário ou nem é compartilhado",
    "No account available to delete." : "Não há contas a excluir.",
    "Poll" : "Enquete",
    "Password needs to be set" : "É necessário definir uma senha",
    "Uploading the file failed" : "Falha no upload do arquivo",
    "No image file provided" : "Nenhum arquivo de imagem fornecido",
    "File is too big" : "O arquivo é muito grande",
    "Invalid file provided" : "Arquivo fornecido inválido",
    "Invalid image" : "Imagem inválida",
    "Unknown filetype" : "Tipo de arquivo desconhecido",
    "Talk mentions" : "Menções na conversa",
    "More conversations" : "Mais conversas",
    "Say hi to your friends and colleagues!" : "Diga oi para seus amigos e colegas!",
    "No unread mentions" : "Não há citações não lidas",
    "Call in progress" : "Chamada em andamento",
    "You were mentioned" : "Você foi citado",
    "Write to conversation" : "Escreva na conversa",
    "Writes event information into a conversation of your choice" : "Grava informações do evento em uma conversa de sua escolha",
    "Missing email field in header line" : "Campo de e-mail ausente na linha de cabeçalho",
    "Following lines are invalid: %s" : "As seguintes linhas estão inválidas: %s",
    "%1$s invited you to conversation \"%2$s\"." : "%1$s convidou você para a conversa \"%2$s\".",
    "You were invited to conversation \"%s\"." : "Você foi convidado para a conversa \"%s\".",
    "Conversation invitation" : "Convite para conversa",
    "Scheduled time" : "Horário agendado",
    "Description" : "Descrição",
    "You can also dial-in via phone with the following details" : "Você também pode discar via telefone com os seguintes detalhes",
    "Dial-in information" : "Informação de discagem",
    "Meeting ID" : "ID da reunião",
    "Your PIN" : "Seu PIN",
    "Click the button below to join the lobby now." : "Clique no botão abaixo para entrar na sala de espera agora.",
    "Click the link below to join the lobby now." : "Clique no link abaixo para entrar na sala de espera agora.",
    "Join lobby for \"%s\"" : "Entrar na sala de espera para \"%s\"",
    "Click the button below to join the conversation now." : "Clique no botão abaixo para entrar na conversa agora.",
    "Click the link below to join the conversation now." : "Clique no link abaixo para entrar na conversa agora.",
    "Join \"%s\"" : "Entrar na \"%s\"",
    "Meeting" : "Reunião",
    "Password request: %s" : "Pedido de senha: %s",
    "Private conversation" : "Conversa privada",
    "Deleted user (%s)" : "Excluir usuário (%s)",
    "Failed to upload call recording" : "Falha ao fazer upload da gravação da chamada",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "O servidor de gravação falhou ao fazer upload da gravação da chamada {call}. Por favor, entre em contato com a administração.",
    "Share to chat" : "Compartilhar no bate-papo",
    "Dismiss notification" : "Dispensar notificação",
    "Call recording now available" : "Gravação da chamada agora está disponível",
    "The recording for the call in {call} was uploaded to {file}." : "A gravação da chamada em {call} foi carregada em {file}.",
    "Transcript now available" : "Transcrição disponível",
    "The transcript for the call in {call} was uploaded to {file}." : "A transcrição para a chamada em {call} foi carregada em {file}.",
    "Failed to transcript call recording" : "Falha ao transcrever gravação da chamada",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "O servidor falhou ao transcrever a gravação em {file} para a chamada em {call}. Por favor, entre em contato com a administração.",
    "Call summary now available" : "Resumo da chamada agora está disponível",
    "The summary for the call in {call} was uploaded to {file}." : "O resumo para a chamada em {call} foi carregado para {file}.",
    "Failed to summarize call recording" : "Falha ao resumir a gravação da chamada",
    "The server failed to summarize the recording at {file} for the call in {call}. Please reach out to the administration." : "O servidor falhou ao resumir a gravação em {file} para a chamada em {call}. Por favor, entre em contato com a administração.",
    "{user1} invited you to join {roomName} on {remoteServer}" : "{user1} convidou você para entrar na sala {roomName} em {remoteServer}",
    "Accept" : "Aceitar",
    "Decline" : "Recusar",
    "{user1} invited you to a federated conversation" : "{user1} convidou você para uma conversa federada",
    "Someone reacted" : "Alguém reagiu",
    "New message" : "Nova mensagem",
    "Reminder" : "Lembrete",
    "Someone mentioned you" : "Alguém mencionou você",
    "Notification" : "Notificação",
    "Someone reacted in a private conversation" : "Alguém reagiu em uma conversa privada",
    "You received a message in a private conversation" : "Você recebeu uma mensagem em uma conversa privada",
    "Reminder in a private conversation" : "Lembrete em uma conversa privada",
    "Someone mentioned you in a private conversation" : "Alguém mencionou você em uma conversa privada",
    "Notification in a private conversation" : "Notificação em uma conversa privada",
    "Reminder: You in {call}" : "Lembrete: Você em {call}",
    "Reminder: {user} in {call}" : "Lembrete: {user} em {call}",
    "Reminder: Deleted user in {call}" : "Lembrete: Usuário excluído em {call}",
    "Reminder: {guest} (guest) in {call}" : "Lembrete: {guest} (convidado) em {call}",
    "Reminder: Guest in {call}" : "Lembrete: Convidado em {call}",
    "{user} reacted with {reaction}" : "{user} reagiu com {reaction}",
    "{user} reacted with {reaction} in {call}" : "{user} reagiu com {reaction} em {call}",
    "Deleted user reacted with {reaction} in {call}" : "Usuário excluído reagiu com {reaction} em {call}",
    "{guest} (guest) reacted with {reaction} in {call}" : "{guest} (convidado) reagiu com {reaction} em {call}",
    "Guest reacted with {reaction} in {call}" : "Convidado reagiu com {reaction} em {call}",
    "{user} in {call}" : "{user} em {call}",
    "Deleted user in {call}" : "Usuário excluído de {call}",
    "{guest} (guest) in {call}" : "{guest} (convidado) em {call}",
    "Guest in {call}" : "Convidado em {call}",
    "{user} sent you a private message" : "{user} te enviou uma mensagem privada",
    "{user} sent a message in conversation {call}" : "{user} enviou uma mensagem na conversa {call}",
    "A deleted user sent a message in conversation {call}" : "Um usuário excluído enviou uma mensagem na conversa {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (guest) enviou uma mensagem na conversa {call}",
    "A guest sent a message in conversation {call}" : "Um convidado enviou uma mensagem na conversa {call}",
    "{user} replied to your private message" : "{user} respondeu a sua mensagem privada",
    "{user} replied to your message in conversation {call}" : "{user} respondeu à sua mensagem na conversa {call}",
    "A deleted user replied to your message in conversation {call}" : "Um usuário removido respondeu à sua mensagem na conversa {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (guest) respondeu sua mensagem na conversa {call}",
    "A guest replied to your message in conversation {call}" : "Um convidado respondeu à sua mensagem na conversa {call}",
    "Reminder: You in private conversation {call}" : "Lembrete: Você na conversa privada {call}",
    "Reminder: A deleted user in private conversation {call}" : "Lembrete: Um usuário excluído na conversa privada {call}",
    "Reminder: {user} in private conversation" : "Lembrete: {user} em uma conversa privada",
    "Reminder: You in conversation {call}" : "Lembrete: Você na conversa {call}",
    "Reminder: {user} in conversation {call}" : "Lembrete: {user} na conversa {call}",
    "Reminder: A deleted user in conversation {call}" : "Lembrete: Um usuário excluído na conversa {call}",
    "Reminder: {guest} (guest) in conversation {call}" : "Lembrete: {guest} (convidado) na conversa {call}",
    "Reminder: A guest in conversation {call}" : "Lembrete: Um convidado na conversa {call}",
    "{user} reacted with {reaction} to your private message" : "{user} reagiu com {reaction} à sua mensagem privada",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} reagiu com {reaction} à sua mensagem na conversa {call}",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "Um usuário excluído reagiu com {reaction} à sua mensagem na conversa {call}",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest} (convidado) reagiu com {reaction} à sua mensagem na conversa {call}",
    "A guest reacted with {reaction} to your message in conversation {call}" : "Um convidado reagiu com {reaction} à sua mensagem na conversa {call}",
    "{user} mentioned you in a private conversation" : "{user} mencionou você em uma conversa privada",
    "{user} mentioned group {group} in conversation {call}" : "{user} mencionou o grupo {group} na conversa {call}",
    "{user} mentioned team {team} in conversation {call}" : "{user} mencionou a equipe {team} na conversa {call}",
    "{user} mentioned everyone in conversation {call}" : "{user} mencionou todas as pessoas na conversa {call}",
    "{user} mentioned you in conversation {call}" : "{user} mencionou você na conversa {call}",
    "A deleted user mentioned group {group} in conversation {call}" : "Um usuário excluído mencionou o grupo {group} na conversa {call}",
    "A deleted user mentioned team {team} in conversation {call}" : "Um usuário excluído mencionou a equipe {team} na conversa {call}",
    "A deleted user mentioned everyone in conversation {call}" : "Um usuário excluído mencionou todas as pessoas na conversa {call}",
    "A deleted user mentioned you in conversation {call}" : "Um usuário excluído mencionou você na conversa {call}",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{guest} (convidado) mencionou o {group} na conversa {call}",
    "{guest} (guest) mentioned team {team} in conversation {call}" : "{guest} (convidado) mencionou a equipe {team} na conversa {call}",
    "{guest} (guest) mentioned everyone in conversation {call}" : "{guest} (convidado) mencionou todas as pessoas na conversa {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (guest) citou você na conversa {call}",
    "A guest mentioned group {group} in conversation {call}" : "Um convidado mencionou o grupo {group} na conversa {call}",
    "A guest mentioned team {team} in conversation {call}" : "Um convidado mencionou a equipe {team} na conversa {call}",
    "A guest mentioned everyone in conversation {call}" : "Um convidado mencionou todas as pessoas na conversa {call}",
    "A guest mentioned you in conversation {call}" : "Um convidado mencionou você na conversa {call}",
    "View message" : "Exibir mensagem",
    "Dismiss reminder" : "Dispensar lembrete",
    "View chat" : "Ver o chat",
    "{user} invited you to a group conversation: {call}" : "{user} convidou você para uma conversa em grupo: {call}",
    "Join call" : "Entrar na chamada",
    "Answer call" : "Atender chamada",
    "{user} would like to talk with you" : "{user} gostaria de falar com você",
    "Call back" : "Ligar de volta",
    "You missed a call from {user}" : "Você perdeu uma ligação de {user}",
    "Accept call" : "Atender chamada",
    "Incoming phone call from {call}" : "Chamada recebida de {call}",
    "You missed a phone call from {call}" : "Você perdeu uma chamada de {call}",
    "A group call has started in {call}" : "Uma chamada de grupo foi iniciada em {call}",
    "You missed a group call in {call}" : "Você perdeu uma ligação em grupo em {call}",
    "{email} is requesting the password to access {file}" : "{email} está solicitando a senha para acessar {file}",
    "{email} tried to request the password to access {file}" : "{email} tentou solicitar a senha para acessar {file}",
    "Someone is requesting the password to access {file}" : "Alguém está solicitando a senha para acessar {file}",
    "Someone tried to request the password to access {file}" : "Alguém tentou solicitar a senha para acessar {file}",
    "Open settings" : "Abrir as configurações",
    "Hosted signaling server added" : "Servidor de sinalização hospedado adicionado",
    "The hosted signaling server is now configured and will be used." : "O servidor de sinalização hospedado está agora configurado e será usado.",
    "Hosted signaling server removed" : "Servidor de sinalização hospedado removido",
    "The hosted signaling server was removed and will not be used anymore." : "O servidor de sinalização hospedado foi removido e não será mais usado.",
    "Hosted signaling server changed" : "Servidor de sinalização hospedado alterado",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "O servidor de sinalização hospedado mudou seu status de \"{oldstatus}\" para \"{newstatus}\".",
    "pending" : "pendente",
    "active" : "ativo",
    "expired" : "expirado",
    "blocked" : "bloqueado",
    "error" : "erro",
    "The certificate of {host} expires in {days} days" : "O certificado de {host} expirará em {days} dias",
    "The certificate of {host} expired" : "O certificado de {host} expirou",
    "Contact via Talk" : "Contato via Talk",
    "Open Talk" : "Abrir Talk",
    "Default" : "Padrão",
    "Send messages, create threads, and start voice and video calls." : "Envie mensagens, crie fios e inicie chamadas de voz e vídeo.",
    "Presentation" : "Apresentação",
    "Voice room" : "Sala de voz",
    "Directly join the call, ideal for catch-ups or spontaneous meetings." : "Entre diretamente na chamada, ideal para colocar o papo em dia ou para reuniões espontâneas.",
    "Webinar" : "Webinário",
    "Conversations" : "Conversas",
    "Messages in current conversation" : "Mensagens na conversa atual",
    "{user}" : "{user}",
    "Messages" : "Mensagens",
    "{user} in {conversation}" : "{user} em {conversation}",
    "Messages in other conversations" : "Mensagens em outras conversas",
    "One-to-one rooms always need to show the other users avatar" : "As salas individuais sempre precisam mostrar o avatar do outro usuário",
    "Invalid emoji character" : "Caractér de emoji inválido",
    "Invalid background color" : "Cor de plano de fundo inválida",
    "Avatar image is not square" : "A imagem do avatar não é quadrada",
    "Room {number}" : "Sala {number}",
    "Other" : "Outro",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "Falha ao solicitar a avaliação porque o servidor está inacessível. Tente novamente mais tarde.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "Há um problema com a autenticação desta instância. Talvez não seja acessível externamente para verificar sua URL.",
    "Something unexpected happened." : "Algo inesperado aconteceu.",
    "The URL is invalid." : "A URL é inválida.",
    "An HTTPS URL is required." : "Uma URL HTTPS é necessária.",
    "The email address is invalid." : "O e-mail é inválido.",
    "The language is invalid." : "O idioma é inválido.",
    "The country is invalid." : "O país é inválido.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "Há um problema com a solicitação da avaliação. Verifique os logs para obter mais informações.",
    "Too many requests are send from your servers address. Please try again later." : "Muitas solicitações foram enviadas do endereço do servidor. Tente novamente mais tarde.",
    "There is already a trial registered for this Nextcloud instance." : "Já existe uma avaliação registrada para esta instância do Nextcloud.",
    "Something unexpected happened. Please try again later." : "Algo inesperado aconteceu. Tente novamente mais tarde.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "Falha ao solicitar a avaliação porque o servidor de avaliação se comportou incorretamente. Tente novamente mais tarde.",
    "Trial requested but failed to get account information. Please check back later." : "Avaliação solicitada mas falhou ao obter informações da conta. Tente novamente mais tarde.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "Há um problema com a autenticação desta solicitação. Talvez não seja acessível externamente para verificar seu URL.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "Erro ao buscar informações da conta porque o servidor de avaliação se comportou incorretamente. Tente novamente mais tarde.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "Há um problema ao buscar as informações da conta. Verifique os logs para obter mais informações.",
    "There is no such account registered." : "Não há registro desta conta.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "Falha ao buscar informações da conta porque o servidor de avaliação está inacessível. Por favor, volte mais tarde.",
    "Deleting the hosted signaling server account failed. Please check back later." : "A exclusão da conta do servidor de sinalização hospedada falhou. Tente novamente mais tarde.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Falha ao excluir a conta porque o servidor de avaliação se comportou incorretamente. Por favor, tente novamente mais tarde.",
    "There is a problem with deleting the account. Please check your logs for further information." : "Há um problema com a exclusão da conta. Verifique os logs para obter mais informações.",
    "Too many requests are sent from your servers address. Please try again later." : "Muitas solicitações são enviadas dos endereços dos seus servidores. Tente novamente mais tarde.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "Falha ao excluir a conta porque o servidor de avaliação está inacessível. Tente novamente mais tarde.",
    "Note to self" : "Nota para si mesmo",
    "A place for your private notes, thoughts and ideas" : "Um lugar para suas notas, pensamentos e ideias privados",
    "Transcript is AI generated and may contain mistakes" : "A transcrição é gerada por IA e pode conter erros",
    "Summary is AI generated and may contain mistakes" : "O resumo é gerado por IA e pode conter erros",
    "Let's get started!" : "Vamos começar!",
    "**Nextcloud Talk** is a secure, self-hosted communication platform that integrates seamlessly with the Nextcloud ecosystem.\n\n#### Key Features of Nextcloud Talk:\n\n* Chat and messaging in private and group chats\n* Voice and video calls\n* File sharing and integration with other Nextcloud apps\n* Customizable conversation settings, moderation and privacy controls\n* Web, desktop and mobile (iOS and Android)\n* Private & secure communication\n\n Find out more in the [user documentation](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html)." : "**Nextcloud Talk** é uma plataforma de comunicação segura e auto-hospedada que se integra perfeitamente ao ecossistema Nextcloud.\n\n#### Principais Recursos do Nextcloud Talk:\n\n* Bate-papo e mensagens em bate-papos privados e em grupo\n* Chamadas de voz e vídeo\n* Compartilhamento de arquivos e integração com outros aplicativos Nextcloud\n* Configurações de conversa personalizáveis, moderação e controles de privacidade\n* Web, desktop e celular (iOS e Android)\n* Comunicação privada & segura\n\nSaiba mais na [documentação do usuário](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html).",
    "# Welcome to Nextcloud Talk\n\nNextcloud Talk is a private and powerful messaging app that integrates with Nextcloud. Chat in private or group conversations, collaborate over voice and video calls, organize webinars and events, customize your conversations and more." : "# Bem-vindo ao Nextcloud Talk\n\nNextcloud Talk é um aplicativo de mensagens privado e poderoso que se integra ao Nextcloud. Converse em conversas privadas ou em grupo, colabore em chamadas de voz e vídeo, organize webinários e eventos, personalize suas conversas e muito mais.",
    "## 🎨 Format texts to create rich messages\n\nIn Nextcloud Talk, you can use Markdown syntax to format your messages. For example, apply **bold** or *italic* formatting, or `highlight texts as code`. You can even create tables and add headings to your text.\n\nNeed to fix a typo or change formatting? Edit your message by clicking \"Edit message\" in the message menu." : "## 🎨 Formatar textos para criar mensagens ricas\n\nNo Nextcloud Talk, você pode usar a sintaxe Markdown para formatar suas mensagens. Por exemplo, aplique a formatação **negrito** ou *itálico*, ou `destaque textos como código`. Você pode até mesmo criar tabelas e adicionar cabeçalhos ao seu texto.\n\nPrecisa corrigir um erro de digitação ou alterar a formatação? Edite sua mensagem clicando em \"Editar mensagem\" no menu de mensagens.",
    "## 🔗 Add attachments and links\n\nAttach files from your Nextcloud Hub using the \"+\" button. Share items from Files and various Nextcloud apps. Some apps even support interactive widgets, for example, the Text app." : "## 🔗 Adicionar anexos e links\n\nAnexe arquivos do seu Nextcloud Hub usando o botão \"+\". Compartilhe itens de Arquivos e de vários aplicativos do Nextcloud. Alguns aplicativos até suportam widgets interativos, por exemplo, o aplicativo Texto.",
    "## 💭 Let the conversations flow: mention users, react to messages and more\n\nYou can mention everybody in the conversation by using %s or mention specific participants by typing \"@\" and picking their name from the list." : "## 💭 Deixe as conversas fluírem: mencione usuários, reaja a mensagens e muito mais\n\nVocê pode mencionar todos na conversa usando %s ou mencionar participantes específicos digitando \"@\" e escolhendo o nome deles na lista.",
    "You can reply to messages, forward them to other chats and people, or copy message content." : "Você pode responder a mensagens, encaminhá-las para outros bate-papos e pessoas ou copiar o conteúdo da mensagem.",
    "## ✨ Do more with Smart Picker\n\nSimply type \"/\" or go to the \"+\" menu to open the Smart Picker where you can attach various content to your messages. You can configure the Smart Picker to be able to add items from Nextcloud apps, GIFs, map locations, AI generated content and much more." : "## ✨ Faça mais com o Seletor Inteligente\n\nBasta digitar \"/\" ou acessar o menu \"+\" para abrir o Seletor Inteligente, onde você pode anexar vários conteúdos às suas mensagens. Você pode configurar o Seletor Inteligente para poder adicionar itens de aplicativos Nextcloud, GIFs, localizações de mapas, conteúdo gerado por IA e muito mais.",
    "## ⚙️ Manage conversation settings\n\nIn the conversation menu, you can access various settings to manage your conversations, such as:\n* Edit conversation info\n* Manage notifications\n* Apply numerous moderation rules\n* Configure access and security\n* Enable bots\n* and more!" : "## ⚙️ Gerenciar configurações de conversa\n\nNo menu de conversas, você pode acessar várias configurações para gerenciar suas conversas, como:\n* Editar informações da conversa\n* Gerenciar notificações\n* Aplicar várias regras de moderação\n* Configurar acesso e segurança\n* Ativar bots\n* e muito mais!",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Emirados Árabes Unidos",
    "Afghanistan" : "Afeganistão",
    "Antigua and Barbuda" : "Antígua e Barbuda",
    "Anguilla" : "Anguila",
    "Albania" : "Albânia",
    "Armenia" : "Armênia",
    "Angola" : "Angola",
    "Antarctica" : "Antártica",
    "Argentina" : "Argentina",
    "American Samoa" : "Samoa Americana",
    "Austria" : "Áustria",
    "Australia" : "Austrália",
    "Aruba" : "Aruba",
    "Åland Islands" : "Ilhas Aland",
    "Azerbaijan" : "Azerbaijão",
    "Bosnia and Herzegovina" : "Bósnia e Herzegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Bélgica",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgária",
    "Bahrain" : "Barém",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "São Bartolomeu",
    "Bermuda" : "Bermudas",
    "Brunei Darussalam" : "Brunei Darussalam",
    "Bolivia, Plurinational State of" : "Bolívia, Estado Plurinacional da",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Santo Eustáquio e Saba",
    "Brazil" : "Brasil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Butão",
    "Bouvet Island" : "Ilha Bouvet",
    "Botswana" : "Botsuana",
    "Belarus" : "Belarus",
    "Belize" : "Belize",
    "Canada" : "Canadá",
    "Cocos (Keeling) Islands" : "Ilhas Cocos (Keeling)",
    "Congo, the Democratic Republic of the" : "Congo, República Democrática do",
    "Central African Republic" : "República Centro-Africana",
    "Congo" : "Congo",
    "Switzerland" : "Suíça",
    "Côte d'Ivoire" : "Costa do Marfim",
    "Cook Islands" : "Ilhas Cook",
    "Chile" : "Chile",
    "Cameroon" : "Camarões",
    "China" : "China",
    "Colombia" : "Colômbia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Cabo Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Ilha do Natal",
    "Cyprus" : "Chipre",
    "Czechia" : "República Checa",
    "Germany" : "Alemanha",
    "Djibouti" : "Djibuti",
    "Denmark" : "Dinamarca",
    "Dominica" : "Dominica",
    "Dominican Republic" : "República Dominicana",
    "Algeria" : "Algéria",
    "Ecuador" : "Equador",
    "Estonia" : "Estônia",
    "Egypt" : "Egito",
    "Western Sahara" : "Saara Ocidental",
    "Eritrea" : "Eritréia",
    "Spain" : "Espanha",
    "Ethiopia" : "Etiópia",
    "Finland" : "Finlândia",
    "Fiji" : "Fiji",
    "Falkland Islands (Malvinas)" : "Ilhas Falkland (Malvinas)",
    "Micronesia, Federated States of" : "Micronésia, Estados Federados da",
    "Faroe Islands" : "ilhas Faroé",
    "France" : "França",
    "Gabon" : "Gabão",
    "United Kingdom of Great Britain and Northern Ireland" : "Reino Unido da Grã-Bretanha e Irlanda do Norte",
    "Grenada" : "Granada",
    "Georgia" : "Georgia",
    "French Guiana" : "Guiana Francesa",
    "Guernsey" : "Guernsey",
    "Ghana" : "Gana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Groenlândia",
    "Gambia" : "Gâmbia",
    "Guinea" : "Guiné",
    "Guadeloupe" : "Guadalupe",
    "Equatorial Guinea" : "Guiné Equatorial",
    "Greece" : "Grécia",
    "South Georgia and the South Sandwich Islands" : "Geórgia do Sul e Ilhas Sandwich do Sul",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guiné-Bissau",
    "Guyana" : "Guiana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Ilha Heard e Ilhas McDonald",
    "Honduras" : "Honduras",
    "Croatia" : "Croácia",
    "Haiti" : "Haiti",
    "Hungary" : "Hungria",
    "Indonesia" : "Indonésia",
    "Ireland" : "Irlanda",
    "Israel" : "Israel",
    "Isle of Man" : "Ilha de Man",
    "India" : "Índia",
    "British Indian Ocean Territory" : "Território Britânico do Oceano Índico",
    "Iraq" : "Iraque",
    "Iran, Islamic Republic of" : "Irã (Republic Islâmica do)",
    "Iceland" : "Islândia",
    "Italy" : "Itália",
    "Jersey" : "Jersey",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordânia",
    "Japan" : "Japão",
    "Kenya" : "Quênia",
    "Kyrgyzstan" : "Quirguistão",
    "Cambodia" : "Camboja",
    "Kiribati" : "Kiribati",
    "Comoros" : "Comores",
    "Saint Kitts and Nevis" : "São Cristóvão e Neves",
    "Korea, Democratic People's Republic of" : "Coreia, República Popular Democrática da",
    "Korea, Republic of" : "Coreia, República da",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Ilhas Cayman",
    "Kazakhstan" : "Cazaquistão",
    "Lao People's Democratic Republic" : "República Popular Democrática do Laos",
    "Lebanon" : "Líbano",
    "Saint Lucia" : "Santa Lúcia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Libéria",
    "Lesotho" : "Lesoto",
    "Lithuania" : "Lituânia",
    "Luxembourg" : "Luxemburgo",
    "Latvia" : "Letônia",
    "Libya" : "Líbia",
    "Morocco" : "Marrocos",
    "Monaco" : "Mônaco",
    "Moldova, Republic of" : "Moldova, República da",
    "Montenegro" : "Montenegro",
    "Saint Martin (French part)" : "São Martinho (parte Francesa)",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Ilhas Marshall",
    "North Macedonia" : "Macedônia do Norte",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongólia",
    "Macao" : "Macau",
    "Northern Mariana Islands" : "Ilhas Marianas do Norte",
    "Martinique" : "Martinica",
    "Mauritania" : "Mauritânia",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Maurício",
    "Maldives" : "Maldivas",
    "Malawi" : "Malawi",
    "Mexico" : "México",
    "Malaysia" : "Malásia",
    "Mozambique" : "Moçambique",
    "Namibia" : "Namíbia",
    "New Caledonia" : "Nova Caledônia",
    "Niger" : "Nigéria",
    "Norfolk Island" : "Ilha Norfolk",
    "Nigeria" : "Nigéria",
    "Nicaragua" : "Nicarágua",
    "Netherlands" : "Holanda",
    "Norway" : "Noruega",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niuê",
    "New Zealand" : "Nova Zelândia",
    "Oman" : "Omã",
    "Panama" : "Panamá",
    "Peru" : "Peru",
    "French Polynesia" : "Polinésia Francesa",
    "Papua New Guinea" : "Papua Nova Guiné",
    "Philippines" : "Filipinas",
    "Pakistan" : "Paquistão",
    "Poland" : "Polônia",
    "Saint Pierre and Miquelon" : "São Pedro e Miquelão",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Porto Rico",
    "Palestine, State of" : "Palestina, Estado da",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguai",
    "Qatar" : "Catar",
    "Réunion" : "Reunião",
    "Romania" : "Romênia",
    "Serbia" : "Sérvia",
    "Russian Federation" : "Federação Russa",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Arábia Saudita",
    "Solomon Islands" : "Ilhas Salomão",
    "Seychelles" : "Seicheles",
    "Sudan" : "Sudão",
    "Sweden" : "Suécia",
    "Singapore" : "Cingapura",
    "Saint Helena, Ascension and Tristan da Cunha" : "Santa Helena, Ascensão e Tristão da Cunha",
    "Slovenia" : "Eslovênia",
    "Svalbard and Jan Mayen" : "Svalbard e Jan Mayen",
    "Slovakia" : "Eslováquia",
    "Sierra Leone" : "Serra Leoa",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somália",
    "Suriname" : "Suriname",
    "South Sudan" : "Sudão do Sul",
    "Sao Tome and Principe" : "São Tome e Príncipe",
    "El Salvador" : "El Salvador",
    "Sint Maarten (Dutch part)" : "São Martinho (parte Holandesa)",
    "Syrian Arab Republic" : "República Árabe da Síria",
    "Eswatini" : "Suazilândia",
    "Turks and Caicos Islands" : "Ilhas Turcas e Caicos",
    "Chad" : "Chade",
    "French Southern Territories" : "Territórios Franceses do Sul",
    "Togo" : "Togo",
    "Thailand" : "Tailândia",
    "Tajikistan" : "Tajiquistão",
    "Tokelau" : "Toquelau",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Turcomenistão",
    "Tunisia" : "Tunísia",
    "Tonga" : "Tonganês",
    "Turkey" : "Turquia",
    "Trinidad and Tobago" : "Trinidade e Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan, Province of China" : "Taiwan, Província da China",
    "Tanzania, United Republic of" : "Tanzânia, República Unida da",
    "Ukraine" : "Ucrânia",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Ilhas Menores Distantes dos Estados Unidos",
    "United States of America" : "Estados Unidos da America",
    "Uruguay" : "Uruguai",
    "Uzbekistan" : "Uzbequistão",
    "Holy See" : "Santa Sé",
    "Saint Vincent and the Grenadines" : "São Vicente e Granadinas",
    "Venezuela, Bolivarian Republic of" : "Venezuela, República Bolivariana da",
    "Virgin Islands, British" : "Ilhas Virgens, Britânicas",
    "Virgin Islands, U.S." : "Ilhas Virgens, U.S.",
    "Viet Nam" : "Vietnã",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis e Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Iêmen",
    "Mayotte" : "Maiote",
    "South Africa" : "África do Sul",
    "Zambia" : "Zâmbia",
    "Zimbabwe" : "Zimbábue",
    "Background blur" : "Desfoque de fundo",
    "Could not check for WASM loading support. Please check manually if your web server serves `.wasm` files." : "Não foi possível verificar o suporte ao carregamento do WASM. Verifique manualmente se o seu servidor web serve arquivos `.wasm`.",
    "Your web server is not properly set up to deliver `.wasm` files. This is typically an issue with the Nginx configuration. For background blur it needs an adjustment to also deliver `.wasm` files. Compare your Nginx configuration to the recommended configuration in our documentation." : "Seu servidor web não está configurado corretamente para entregar arquivos `.wasm`. Normalmente, isso é um problema com a configuração do Nginx. Para desfoque de fundo, é necessário um ajuste para entregar também arquivos `.wasm`. Compare sua configuração do Nginx com a configuração recomendada em nossa documentação.",
    "Talk configuration values" : "Valores de configuração do Talk",
    "Forcing a call duration is only supported with system cron. Please enable system cron or remove the `max_call_duration` configuration." : "Forçar uma duração de chamada só é suportado com o cron do sistema. Habilite o cron do sistema ou remova a configuração `max_call_duration`.",
    "Small `max_call_duration` values (currently set to %d) are not enforceable due to technical limitations. The background job is only executed every 5 minutes, so use at own risk." : "Valores pequenos de `max_call_duration` (atualmente definido como %d) não são aplicáveis ​​devido a limitações técnicas. O trabalho em segundo plano é executado apenas a cada 5 minutos, então use por sua conta e risco.",
    "Federation" : "Federação",
    "It is highly recommended to configure \"memcache.locking\" when Talk Federation is enabled." : "É altamente recomendável configurar \"memcache.locking\" quando o Talk Federation estiver ativado.",
    "High-performance backend" : "Back-end de alto desempenho",
    "No High-performance backend configured - Running Nextcloud Talk without the High-performance backend only scales for very small calls (max. 2-3 participants). Please set up the High-performance backend to ensure calls with multiple participants work seamlessly." : "Nenhum back-end de alto desempenho configurado - A execução do Nextcloud Talk sem o back-end de alto desempenho só é dimensionada para chamadas muito pequenas (máximo de 2 a 3 participantes). Por favor, configure o back-end de alto desempenho para garantir que as chamadas com vários participantes funcionem sem problemas.",
    "Running the High-performance backend \"conversation_cluster\" mode is deprecated and will no longer be supported in the upcoming version. The High-performance backend supports real clustering nowadays which should be used instead." : "A execução do modo \"conversation_cluster\" de back-end de alto desempenho está obsoleta e não será mais suportada na próxima versão. O back-end de alto desempenho atualmente suporta clustering real, que deve ser usado em vez disso.",
    "Defining multiple High-performance backends is deprecated and will no longer be supported in the upcoming version. Instead a load-balancer should be set up together with clustered signaling servers and configured in the Talk settings." : "Definir múltiplos back-ends de alto desempenho está obsoleto e não será mais suportado na próxima versão. Em vez disso, um balanceador de carga deve ser configurado junto com servidores de sinalização em cluster e configurado nas configurações do Talk.",
    "The stored public key for used algorithm %1$s does not match the stored private key. Run %2$s to fix the issue." : "A chave pública armazenada para o algoritmo %1$s usado não corresponde à chave privada armazenada. Execute %2$s para corrigir o problema.",
    "High-performance backend not configured correctly. Run %s for details." : "O back-end de alto desempenho não está configurado corretamente. Execute %s para obter detalhes.",
    "High-performance backend not configured correctly" : "Back-end de alto desempenho não configurado corretamente",
    "Error: Cannot connect to server" : "Erro: Não foi possível conectar ao servidor",
    "Error: Server did not respond with proper JSON" : "Erro: Servidor não respondeu com o JSON apropriado",
    "Error: Certificate expired" : "Erro: Certificado expirado",
    "Error: System times of Nextcloud server and High-performance backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Erro: Os horários do sistema do servidor Nextcloud e do servidor de back-end de alto desempenho estão fora de sincronia. Por favor, certifique-se de que ambos os servidores estejam conectados a um servidor de tempo ou sincronize manualmente o horário deles.",
    "Could not get version" : "Não foi possível obter a versão",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "Erro: Versão em execução: {version}; O servidor precisa ser atualizado para ser compatível com esta versão do Talk",
    "Error: Server responded with: {error}" : "Erro: Servidor respondeu com: {error}",
    "Error: Unknown error occurred" : "Erro: Ocorreu um erro desconhecido",
    "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}" : "Aviso: Versão em execução: {version}; O servidor não oferece suporte a todos os recursos desta versão do Talk, recursos ausentes: {features}",
    "It is highly recommended to configure a memory cache when running Nextcloud Talk with a High-performance backend." : "É altamente recomendável configurar um cache de memória ao executar Nextcloud Talk com back-end de alto desempenho.",
    "Client Push" : "Client Push",
    "Client Push is installed, this improves the punctuality of Talk notifications." : "O Client Push está instalado, o que melhora a pontualidade das notificações do Talk.",
    "{notify_push} is not installed. This may lead to delayed Talk notifications." : "{notify_push} não está instalado. Isso pode causar atrasos nas notificações do Talk.",
    "Recording backend" : "Back-end de gravação",
    "Using the recording backend requires a High-performance backend." : "Usar o back-end de gravação requer um back-end de alto desempenho.",
    "No recording backend configured" : "Nenhum back-end de gravação configurado",
    "SIP configuration" : "Configuração SIP",
    "Using the SIP functionality requires a High-performance backend." : "O uso da funcionalidade SIP requer um back-end de alto desempenho.",
    "Assigned Talk phone numbers must not start with + or 0. Please remove or update the following numbers:\n{list}" : "Os números de telefone atribuídos ao Talk não devem começar com + ou 0. Remova ou atualize os seguintes números:\n{list}",
    "No SIP backend configured" : "Nenhum back-end SIP configurado",
    "Invalid date, date format must be YYYY-MM-DD" : "Data inválida, o formato deve ser YYYY-MM-DD",
    "Conversation not found" : "Conversa não encontrada",
    "Path is already shared with this conversation" : "O caminho já está compartilhado com esta conversa",
    "Chat, video & audio-conferencing using WebRTC" : "Bate-papo, vídeo e audioconferência usando o WebRTC",
    "Chat, video & audio-conferencing using WebRTC\n\n* 💬 **Chat** Nextcloud Talk comes with a simple text chat, allowing you to share or upload files from your Nextcloud Files app or local device and mention other participants.\n* 👥 **Private, group, public and password protected calls!** Invite someone, a whole group or send a public link to invite to a call.\n* 🌐 **Federated chats** Chat with other Nextcloud users on their servers\n* 💻 **Screen sharing!** Share your screen with the participants of your call.\n* 🚀 **Integration with other Nextcloud apps** like Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck, and many more.\n* 🌉 **Sync with other chat solutions** With [Matterbridge](https://github.com/42wim/matterbridge/) being integrated in Talk, you can easily sync a lot of other chat solutions to Nextcloud Talk and vice-versa." : "Bate-papo, vídeo & audioconferência usando WebRTC\n\n* 💬 **Bate-papo** Nextcloud Talk vem com um bate-papo de texto simples, permitindo que você compartilhe ou carregue arquivos de seu aplicativo Nextcloud Arquivos ou dispositivo local e mencione outros participantes.\n* 👥 **Chamadas privadas, em grupo, públicas e protegidas por senha!** Convide alguém, um grupo inteiro ou envie um link público para convidar para uma chamada.\n* 🌐 **Bate-papos federados** Converse com outros usuários do Nextcloud nos servidores deles\n* 💻 **Compartilhamento de tela!** Compartilhe sua tela com os participantes da sua chamada.\n* 🚀 **Integração com outros aplicativos Nextcloud** como Arquivos, Calendário, Status do usuário, Painel, Fluxo, Mapas, Seletor Inteligente, Contatos, Deck e muitos mais.\n* 🌉 **Sincronização com outras soluções de bate-papo** Com a integração do [Matterbridge](https://github.com/42wim/matterbridge/) no Talk, você pode sincronizar facilmente muitas outras soluções de bate-papo com o Nextcloud Talk e vice-versa.",
    "Leave call" : "Sair da chamada",
    "Navigating away from the page will leave the call in {conversation}" : "Se você sair da página, sairá da ligação com {conversation}",
    "Stay in call" : "Permanecer na chamada",
    "Error occurred when getting the conversation information" : "Ocorreu um erro ao obter as informações da conversa",
    "Discuss this file" : "Discutir sobre este arquivo",
    "Share this file with others to discuss it" : "Compartilhe este arquivo com outros para discuti-lo",
    "Share this file" : "Compartilhar este arquivo",
    "Join conversation" : "Juntar-se à conversa",
    "This conversation is password-protected." : "Esta conversa é protegida por senha.",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "Detectamos várias tentativas de senhas inválidas de seu IP. Portanto, sua próxima tentativa será limitada a 30 segundos.",
    "The password is wrong. Try again." : "Senha incorreta. Tente novamente.",
    "Password" : "Senha",
    "Submit" : "Enviar",
    "Error requesting the password." : "Erro ao solicitar a senha.",
    "Request password" : "Solicitar senha",
    "This conversation has ended" : "Esta conversa acabou",
    "Error occurred when joining the conversation" : "Ocorreu um erro ao entrar na conversa",
    "Close Talk sidebar" : "Fechar barra lateral do Talk",
    "Open Talk sidebar" : "Abrir barra lateral do Talk",
    "Everyone" : "Qualquer um",
    "Users and moderators" : "Usuários e moderadores",
    "Moderators only" : "Somente moderadores",
    "Disable calls" : "Desativar chamadas",
    "Save changes" : "Salvar alterações",
    "Saving …" : "Salvando...",
    "Saved!" : "Salvo!",
    "Limit to groups" : "Limitar a grupos",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Quando pelo menos um grupo é selecionado, somente pessoas destes grupos podem fazer parte de conversas.",
    "Guests can still join public conversations." : "Convidados ainda podem juntar-se a conversas públicas.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Os usuários que não podem mais usar o aplicativo Talk ainda serão listados como participantes em suas conversas anteriores e também suas mensagens de chat serão mantidas.",
    "Limit using Talk" : "Limitar o uso do Talk",
    "Limit creating a public and group conversation" : "Limitar criar uma conversa pública ou de grupo",
    "Limit creating conversations" : "Limitar criar conversas",
    "Limit starting a call" : "Limitar iniciar uma chamada",
    "Limit starting calls" : "Limitar iniciar chamadas",
    "When a call has started, everyone with access to the conversation can join the call." : "Quando uma chamada é iniciada, todos que têm acesso à conversa podem entrar na chamada.",
    "The following bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Os seguintes bots estão instalados neste servidor. Na documentação, você pode encontrar detalhes sobre como {linkstart1}criar seu próprio bot{linkend} ou uma {linkstart2}lista de bots{linkend} para habilitar em seu servidor.",
    "No bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Nenhum bot está instalado neste servidor. Na documentação, você pode encontrar detalhes sobre como {linkstart1}criar seu próprio bot{linkend} ou uma {linkstart2}lista de bots{linkend} para habilitar em seu servidor.",
    "Description is not provided" : "Descrição não é fornecida",
    "Locked for moderators" : "Trancado para moderadores",
    "Enabled" : "Ativado",
    "Disabled" : "Desativado",
    "Bots settings" : "Configurações de bots",
    "State" : "Estado",
    "Name" : "Nome",
    "Last error" : "Último erro",
    "Total errors count" : "Contagem total de erros",
    "Find more bots" : "Encontre mais bots",
    "Trusted servers can be configured at {linkstart}Sharing settings page{linkend}." : "Servidores confiáveis ​​podem ser configurados na {linkstart}página de configurações de compartilhamento{linkend}.",
    "Beta" : "Beta",
    "Federated chats and calls work already. Attachment handling is coming in a future version." : "Os bate-papos federados e as chamadas federadas já funcionam. O manuseio de anexos será feito em uma versão futura.",
    "Enable Federation in Talk app" : "Ativar Federação no aplicativo Talk",
    "Permissions" : "Permissões",
    "Allow users to be invited to federated conversations" : "Permitir que os usuários sejam convidados para conversas federadas",
    "Allow users to invite federated users into conversation" : "Permitir que os usuários convidem usuários federados para uma conversa",
    "Only allow to federate with trusted servers" : "Permitir federar apenas com servidores confiáveis",
    "When at least one group is selected, only people of the listed groups can invite federated users to conversations." : "Quando pelo menos um grupo for selecionado, somente as pessoas dos grupos listados poderão convidar usuários federados para conversas.",
    "Groups allowed to invite federated users" : "Grupos com permissão para convidar usuários federados",
    "Select groups …" : "Selecionar grupos …",
    "All messages" : "Todas as mensagens",
    "@-mentions only" : "Somente @-mentions",
    "Off" : "Desligar",
    "General settings" : "Configurações gerais",
    "Default notification settings" : "Configurações de notificação padrão",
    "Default group notification" : "Notificação padrão de grupo",
    "Default group notification for new groups" : "Notificação padrão de grupo para novos grupos",
    "Integration into other apps" : "Integração com outros aplicativos",
    "Allow conversations on files" : "Permitir conversas em arquivos",
    "Allow conversations on public shares for files" : "Permitir conversas em compartilhamentos públicos para arquivos",
    "End-to-end encrypted calls" : "Chamadas criptografadas de ponta-a-ponta",
    "Enable encryption" : "Ativar criptografia",
    "End-to-end encrypted calls with a configured SIP bridge require a newer version of the High-performance backend and SIP bridge." : "As chamadas criptografadas de ponta-a-ponta com uma ponte SIP configurada exigem uma versão mais recente do back-end de alto desempenho e da ponte SIP.",
    "Mobile clients do not support end-to-end encrypted calls at the moment." : "No momento, os clientes móveis não oferecem suporte a chamadas criptografadas de ponta-a-ponta.",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "Ao clicar no botão acima, as informações no formulário são enviadas para os servidores da Struktur AG. Você pode encontrar mais informações em {linkstart}spreed.eu{linkend}.",
    "Pending" : "Pendente",
    "Error" : "Erro",
    "Blocked" : "Bloqueado",
    "Active" : "Ativar",
    "Expired" : "Expirado",
    "Never" : "Nunca",
    "The trial could not be requested. Please try again later." : "A avaliação não pôde ser solicitada. Tente novamente mais tarde.",
    "The account could not be deleted. Please try again later." : "Não foi possível excluir a conta. Tente novamente mais tarde.",
    "Hosted High-performance backend" : "Back-end de alto desempenho hospedado",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Nosso parceiro Struktur AG fornece um serviço no qual um servidor de sinalização hospedado pode ser solicitado. Para isso, você só precisa preencher o formulário abaixo e seu Nextcloud solicitará. Depois que o servidor estiver configurado para você, as credenciais serão preenchidas automaticamente. Isso substituirá as configurações existentes do servidor de sinalização.",
    "If your high-performance backend account includes STUN and/or TURN functionality, the settings will be updated accordingly." : "Se sua conta do back-end de alto desempenho incluir a funcionalidade STUN e/ou TURN, as configurações serão atualizadas de acordo.",
    "URL of this Nextcloud instance" : "URL desta instância Nextcloud",
    "Full name of the user requesting the trial" : "Nome completo do usuário que solicitou a avaliação",
    "Email of the user" : "E-mail do usuário ",
    "Language" : "Idioma",
    "Country" : "País",
    "Request signaling server trial" : "Solicitar avaliação de servidor de sinalização",
    "You can see the current status of your hosted signaling server in the following table." : "Você pode ver o status atual do seu servidor de sinalização na tabela a seguir.",
    "Status" : "Status",
    "Created at" : "Criado em",
    "Expires at" : "Expira em",
    "Limits" : "Limites",
    "STUN included" : "STUN incluído",
    "Yes" : "Sim",
    "No" : "Não",
    "TURN included" : "TURN incluído",
    "Delete the signaling server account" : "Excluir a conta do servidor de sinalização",
    "_%n user_::_%n users_" : ["%n usuário","%n usuários","%n usuários"],
    "Installed version: {version}" : "Versão instalada: {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "Você pode instalar o Matterbridge para vincular o Nextcloud Talk a alguns outros serviços, visite a {linkstart1}página do GitHub{linkend} para obter mais detalhes. Baixar e instalar o aplicativo pode demorar um pouco. Caso expire, instale-o manualmente a partir da {linkstart2}Loja de Aplicativos do Nextcloud{linkend}.",
    "Matterbridge binary has incorrect permissions. Please make sure the Matterbridge binary file is owned by the correct user and can be executed. It can be found in \"/…/nextcloud/apps/talk_matterbridge/bin/\"." : "O binário do Matterbridge tem permissões incorretas. Verifique se o arquivo binário do Matterbridge é de propriedade do usuário correto e se pode ser executado. Ele pode ser encontrado em \"/.../nextcloud/apps/talk_matterbridge/bin/\".",
    "Matterbridge binary was not found or couldn't be executed." : "O binário Matterbridge não foi encontrado ou não pôde ser executado.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "Você também pode definir o caminho para o binário Matterbridge manualmente por meio da configuração. Verifique a {linkstart}documentação de integração do Matterbridge{linkend} para mais informações.",
    "Downloading …" : "Baixando…",
    "Install Talk Matterbridge" : "Instalar Talk Matterbridge",
    "An error occurred while installing the Matterbridge app" : "Um erro ocorreu ao instalar o aplicativo Matterbridge",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "Ocorreu um erro ao instalar o Talk Matterbridge. Por favor, instale-o manualmente",
    "Failed to execute Matterbridge binary." : "Erro ao executar o binário Matterbridge.",
    "Matterbridge integration" : "Integração Matterbridge",
    "Enable Matterbridge integration" : "Ativar a integração Matterbridge",
    "Status: Checking connection" : "Status: Verificando conexão",
    "OK: Running version: {version}" : "OK: Versão rodando: {version}",
    "Error: Server seems to be a Signaling server" : "Erro: O servidor parece ser um servidor de Sinalização",
    "Error: System times of Nextcloud server and Recording backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Erro: Os horários do sistema do servidor Nextcloud e do servidor de back-end de gravação estão fora de sincronia. Por favor, certifique-se de que ambos os servidores estejam conectados a um servidor de horário ou sincronize manualmente o horário deles.",
    "Recording backend URL" : "URL de back-end de gravação",
    "Validate SSL certificate" : "Validar o certificado SSL",
    "Delete this server" : "Excluir este servidor",
    "Test this server" : "Testar este servidor",
    "Disabled for all calls" : "Desativado para todas as chamadas",
    "Enabled for all calls" : "Ativado para todas as chamadas",
    "Configurable on conversation level by moderators" : "Configurável no nível da conversa pelos moderadores",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "A configuração PHP \"upload_max_filesize\" ou \"post_max_size\" só permitirá o upload de arquivos de até {maxUpload}.",
    "Recording backend settings saved" : "Configurações de back-end de gravação salvas",
    "Moderators will be allowed to enable consent on conversation level. The consent to be recorded will be required for each participant before joining every call in this conversation." : "Os moderadores terão permissão para ativar o consentimento no nível da conversa. O consentimento para gravação será exigido de cada participante antes de entrar em cada chamada desta conversa.",
    "The consent to be recorded will be required for each participant before joining every call." : "O consentimento para gravação será exigido de cada participante antes de entrar em cada chamada.",
    "The consent to be recorded is not required." : "O consentimento para ser gravado não é necessário.",
    "Recording backend configuration is only possible with a High-performance backend." : "A configuração do back-end de gravação só é possível com um back-end de alto desempenho.",
    "Add a new recording backend server" : "Adicionar um novo servidor de back-end de gravação",
    "Shared secret" : "Segredo compartilhado",
    "Recording consent" : "Consentimento de gravação",
    "Recording transcription" : "Transcrição de gravações",
    "Automatically transcribe call recordings with a transcription provider" : "Transcrever automaticamente gravações de chamadas com um provedor de transcrição",
    "Automatically summarize call recordings with transcription and summary providers" : "Resumir automaticamente gravações de chamadas com provedores de transcrição e resumo",
    "SIP configuration saved!" : "Configuração SIP salva!",
    "SIP configuration is only possible with a High-performance backend." : "A configuração de SIP só é possível com um back-end de alto desempenho.",
    "Enable SIP Dial-out option" : "Ativar opção de discagem SIP",
    "Signaling server needs to be updated to supported SIP Dial-out feature." : "O servidor de sinalização precisa ser atualizado para o recurso de discagem SIP suportado.",
    "Do not show SIP Dial-out caller number" : "Não mostrar o número de discagem SIP",
    "Anonymous number should appear as \"unknown\" or \"withheld number\" to call recipient" : "O número anônimo deve aparecer como \"desconhecido\" ou \"número restrito\" para o destinatário da chamada.",
    "Dial-out number" : "Número de discagem",
    "E164 formatted number used as a fallback caller number for outgoing calls" : "Número no formato E164 usado como número de retorno de chamada para chamadas efetuadas",
    "Dial-out prefix" : "Prefixo de discagem",
    "Prefix to configured user number for outgoing calls (default is `+`)" : "Prefixo para o número de usuário configurado para chamadas efetuadas (o padrão é `+`)",
    "Restrict SIP configuration" : "Restringir configuração SIP",
    "Enable SIP configuration" : "Ativar configuração SIP",
    "Only users of the following groups can enable SIP in conversations they moderate" : "Apenas usuários dos grupos a seguir podem ativar o SIP em conversas que moderam",
    "Phone number (Country)" : "Número do telefone (País)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Estas informações são enviadas em e-mails de convite e também exibidas na barra lateral para todos os participantes.",
    "Nextcloud base URL" : "URL base do Nextcloud",
    "Talk Backend URL" : "URL do Back-end do Talk",
    "WebSocket URL" : "URL de WebSocket",
    "Available features" : "Recursos disponíveis",
    "Error: Websocket connection failed" : "Erro: Falha na conexão Websocket",
    "Error code" : "Código de erro",
    "Error message" : "Mensagem de erro",
    "Error: Websocket connection failed. Check browser console" : "Erro: Falha na conexão do websocket. Verifique o console do navegador",
    "High-performance backend URL" : "URL do back-end de alto desempenho",
    "Missing High-performance backend warning hidden" : "Aviso de falta do back-end de alto desempenho oculto",
    "High-performance backend settings saved" : "Configurações de back-end de alta performance salvas",
    "Nextcloud Talk setup not complete" : "A configuração do Nextcloud Talk não foi concluída",
    "Please note that in calls with more than 2 participants without the High-performance backend, participants will most likely experience connectivity issues and cause high load on participating devices." : "Observe que, em chamadas com mais de 2 participantes sem o back-end de alto desempenho, os participantes provavelmente terão problemas de conectividade e causarão alta carga nos dispositivos participantes.",
    "Install the High-performance backend to ensure calls with multiple participants work seamlessly." : "Instale o back-end de alto desempenho para garantir que as chamadas com vários participantes funcionem sem problemas.",
    "Nextcloud portal" : "Portal do Nextcloud",
    "Quick installation guide" : "Guia de instalação rápida",
    "The High-performance backend is required for calls and conversations with multiple participants. Without the backend, all participants have to upload their own video individually for each other participant, which will most likely cause connectivity issues and a high load on participating devices." : "O back-end de alto desempenho é necessário para chamadas e conversas com vários participantes. Sem o back-end, todos os participantes precisam carregar seus próprios vídeos individualmente para cada um dos outros participantes, o que provavelmente causará problemas de conectividade e alta carga nos dispositivos participantes.",
    "It is highly recommended to set up a distributed cache when using Nextcloud Talk with a High-performance backend." : "É altamente recomendável configurar um cache distribuído ao usar o Nextcloud Talk com um back-end de alto desempenho.",
    "Add High-performance backend server" : "Adicionar servidor de back-end de alto desempenho",
    "Warn about connectivity issues in calls with more than 2 participants" : "Avisar sobre problemas de conectividade em chamadas com mais de 2 participantes",
    "STUN server URL" : "URL do servidor de STUN",
    "The server address is invalid" : "O endereço do servidor é inválido",
    "STUN settings saved" : "Configurações de STUN salvas",
    "STUN servers" : "Servidores STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Um servidor STUN é usado para determinar o endereço IP público dos participantes por detrás de um roteador.",
    "Add a new STUN server" : "Adicionar um novo servidor STUN",
    "{schema} scheme must be used with a domain" : "O esquema {schema} deve ser usado com um domínio",
    "{option1} and {option2}" : "{option1} e {option2}",
    "{option} only" : "{option} apenas",
    "OK: Successful ICE candidates returned by the TURN server" : "OK: Candidatos ICE foram retornados pelo servidor TURN",
    "Error: No working ICE candidates returned by the TURN server" : "Erro: Nenhum candidato ICE foi retornado pelo servidor TURN",
    "Testing whether the TURN server returns ICE candidates" : "Testando para ver se o servidor TURN retorna candidatos ICE",
    "TURN server schemes" : "Esquemas de servidor TURN",
    "TURN server URL" : "URL do servidor de TURN",
    "TURN server secret" : "Segredo do servidor TURN",
    "TURN server protocols" : "Protocolos do servidor TURN",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "Um servidor TURN é usado como proxy do tráfego dos participantes por trás de um firewall. Se os participantes individuais não puderem se conectar a outros, provavelmente será necessário um servidor TURN. Consulte {linkstart}esta documentação{linkend} para obter instruções de configuração. ",
    "TURN settings saved" : "Configurações TURN salvas",
    "TURN servers" : "Servidores TURN",
    "Add a new TURN server" : "Adicionar um novo servidor TURN",
    "Failed" : "Falhou",
    "OK" : "OK",
    "Checking …" : "Verificando …",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "Falha: WebAssembly está desativado ou não é compatível com este navegador. Habilite o WebAssembly ou use um navegador com suporte para fazer a verificação.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "Falha: Os arquivos \".wasm\" e \".tflite\" não foram retornados corretamente pelo servidor web. Verifique a seção \"Requisitos do sistema\" na documentação do Talk.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "OK: Os arquivos \".wasm\" e \".tflite\" foram retornados corretamente pelo servidor da web.",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "Parece que a configuração do PHP e do Apache não é compatível. Observe que o PHP só pode ser usado com o módulo MPM_PREFORK e o PHP-FPM só pode ser usado com o módulo MPM_EVENT.",
    "Web server setup checks" : "Verificações de configuração do servidor web",
    "Files required for virtual background can be loaded" : "Arquivos necessários para o plano de fundo virtual podem ser carregados",
    "Federated user" : "Usuário federado",
    "Assign participants to rooms" : "Atribuir participantes a salas",
    "Configure breakout rooms" : "Configurar salas temáticas",
    "Number of breakout rooms" : "Número de salas temáticas",
    "You can create from 1 to 20 breakout rooms." : "Você pode criar de 1 a 20 salas temáticas.",
    "Assignment method" : "Método de atribuição",
    "Automatically assign participants" : "Atribuir participantes automaticamente",
    "Manually assign participants" : "Atribuir participantes manualmente",
    "Allow participants to choose" : "Permitir que os participantes escolham",
    "Create rooms" : "Criar salas",
    "Confirm" : "Confirmar",
    "Create breakout rooms" : "Criar salas temáticas",
    "Reset" : "Redefinir",
    "Delete breakout rooms" : "Excluir salas temáticas",
    "Room {roomNumber}" : "Sala {roomNumber}",
    "Current breakout rooms and settings will be lost" : "As salas temáticas e as configurações atuais serão perdidas",
    "Cancel" : "Cancelar",
    "Unassigned participants" : "Participantes não atribuídos",
    "Back" : "Voltar",
    "Assign" : "Atribuir",
    "Add participant \"{user}\"" : "Adicionar participante \"{user}\"",
    "Now" : "Agora",
    "Invalid calendar selected" : "Calendário inválido selecionado",
    "Invalid start time selected" : "Hora de início inválida selecionada",
    "Invalid end time selected" : "Hora de término inválida selecionada",
    "Unknown error occurred" : "Ocorreu um erro desconhecido",
    "Sending no invitations" : "Não enviando convites",
    "{participant0} will receive an invitation" : "{participant0} receberá um convite",
    "{participant0} and {participant1} will receive invitations" : "{participant0} e {participant1} receberão um convite",
    "_{participant0}, {participant1} and %n other will receive invitations_::_{participant0}, {participant1} and %n others will receive invitations_" : ["{participant0}, {participant1} e mais %n receberão convites","{participant0}, {participant1} e mais %n receberão convites","{participant0}, {participant1} e mais %n receberão convites"],
    "Invite {user}" : "Convidar {user}",
    "Invite all users and emails in this conversation" : "Convidar todos os usuários e e-mails nesta conversa",
    "Meeting created" : "Reunião criada",
    "Upcoming meetings" : "Próximas reuniões",
    "Loading …" : "Carregando …",
    "No upcoming meetings" : "Nenhuma próxima reunião",
    "Schedule a meeting" : "Agendar uma reunião",
    "Meeting title" : "Título da reunião",
    "From" : "De",
    "To" : "Para",
    "Calendar" : "Calendário",
    "Attendees" : "Participantes",
    "No other participants to send invitations to." : "Não há outros participantes para enviar convites.",
    "Add attendees" : "Adicionar participantes",
    "Save" : "Salvar",
    "Search participants" : "Procurar participantes",
    "No results" : "Nenhum resultado",
    "Done" : "Concluído",
    "Disable live transcription" : "Desativar transcrição em tempo real",
    "Enable live transcription (generated by AI)" : "Ativar transcrição em tempo real (gerada por IA)",
    "Enable live transcription (Live transcriptions app is not installed)" : "Ativar transcrição em tempo real (o aplicativo de transcrição em tempo real não está instalado)",
    "Disable live translation" : "Desativar tradução em tempo real",
    "Enable live translation (generated by AI)" : "Ativar tradução em tempo real (gerada por IA)",
    "Original language" : "Idioma original",
    "Live translations app is not installed" : "O aplicativo de tradução em tempo real não está instalado",
    "Original language: {languageName}" : "Idioma original: {languageName}",
    "Translated language" : "Idioma traduzido",
    "Translated language: {languageName}" : "Idioma traduzido: {languageName}",
    "Raise hand" : "Levantar a mão",
    "Raise hand (R)" : "Levantar a mão (R) ",
    "Lower hand" : "Abaixar a mão",
    "Lower hand (R)" : "Abaixar a mão (R)",
    "Exit full screen (F)" : "Sair da tela cheia (F)",
    "Full screen (F)" : "Tela cheia (F)",
    "Speaker view" : "Visualização de orador",
    "Grid view" : "Vista em grade",
    "Error when trying to load the available live transcription languages" : "Erro ao carregar os idiomas disponíveis para transcrição em tempo real",
    "Failed to enable live transcription" : "Erro ao ativar a transcrição em tempo real",
    "Failed to enable live translations" : "Falha ao ativar a tradução em tempo real",
    "Failed to disable live translations" : "Falha ao desativar a tradução em tempo real",
    "Recording consent is required" : "É necessário o consentimento de gravação",
    "This conversation is read-only" : "Esta conversa é somente leitura",
    "Conversation not found or not joined" : "Conversa não encontrada ou não entrou",
    "Lobby is still active and you're not a moderator" : "A sala de espera ainda está ativa e você não é um moderador",
    "Connection failed" : "Falha na conexão",
    "Reload" : "Recarregar",
    "{nickName} raised their hand." : "{nickName} levantou a mão.",
    "A participant raised their hand." : "Um participante levantou a mão.",
    "Collapse stripe" : "Recolher faixa",
    "Expand stripe" : "Expandir faixa",
    "Previous page of videos" : "Página anterior de vídeos",
    "Next page of videos" : "Próxima página de vídeos",
    "Connecting …" : "Conectando …",
    "Calling …" : "Ligando …",
    "Waiting for {user} to join the call" : "Aguardando a entrada de {user} na chamada",
    "Waiting for others to join the call …" : "Esperando outros entrarem na chamada...",
    "You can invite others in the participant tab of the sidebar" : "Você pode convidar outros na aba de participantes da barra lateral",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Você pode convidar outros na aba de participantes da barra lateral ou compartilhar esse link para convidar outras pessoas!",
    "Share this link to invite others!" : "Compartilhe este link para convidar outros!",
    "Copy link" : "Copiar link",
    "You are not allowed to enable audio" : "Você não tem permissão para habilitar o áudio",
    "No audio. Click to select device" : "Sem áudio. Clique para selecionar um dispositivo",
    "Mute audio" : "Desativar microfone",
    "Mute audio (M)" : "Desativar microfone (M)",
    "Unmute audio" : "Ativar microfone",
    "Unmute audio (M)" : "Ativar microfone (M)",
    "None" : "Nenhum",
    "Select a microphone" : "Selecione um microfone",
    "Select a speaker" : "Selecione um alto-falante",
    "Microphone settings" : "Configurações do microfone",
    "Check devices" : "Verificar dispositivos",
    "Access to camera was denied" : "O acesso à câmera foi negado",
    "Error while accessing camera: It is likely in use by another program" : "Erro ao acessar a câmera: Ela provavelmente está sendo usada por outro programa",
    "Error while accessing camera" : "Erro ao acessar a câmera",
    "You have been muted by a moderator" : "Você foi silenciado por um moderador",
    "Hide presenter video" : "Ocultar vídeo do apresentador",
    "You are not allowed to enable video" : "Você não tem permissão para habilitar o vídeo",
    "No video. Click to select device" : "Sem vídeo. Clique para selecionar um dispositivo",
    "Disable video" : "Desativar vídeo",
    "Disable video (V)" : "Desativar vídeo (V) ",
    "Enable video" : "Ativar vídeo",
    "Enable video (V)" : "Ativar vídeo (V) ",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "Ativar vídeo - Sua conexão será interrompida brevemente ao ativar o vídeo pela primeira vez",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Ativar vídeo (V) - Sua conexão será interrompida brevemente ao ativar o vídeo pela primeira vez",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Ativar vídeo. Sua conexão será brevemente interrompida ao ativar o vídeo pela primeira vez",
    "Select a video device" : "Selecione um dispositivo de vídeo",
    "Show presenter" : "Mostrar apresentador",
    "You" : "Você",
    "Mute" : "Desativar microfone",
    "Muted" : "Microfone desativado",
    "Show screen" : "Exibir tela",
    "Stop following" : "Parar de seguir",
    "Connection could not be established …" : "Não foi possível estabelecer a conexão …",
    "Connection was lost and could not be re-established …" : "A conexão foi perdida e não pôde ser restabelecida …",
    "Connection could not be established. Trying again …" : "Não foi possível estabelecer a conexão. Tentando novamente …",
    "Connection lost. Trying to reconnect …" : "Conexão perdida. Tentando reconectar …",
    "Connection problems …" : "Problemas de conexão ...",
    "Collapse" : "Recolher",
    "Expand" : "Expandir",
    "You need to be logged in to upload files" : "Você precisa fazer login para enviar arquivos",
    "Drop your files to upload" : "Arraste seus arquivos para enviar",
    "Conversation messages" : "Mensagens de conversa",
    "Scroll to bottom" : "Rolar para baixo",
    "Post message" : "Postar mensagem",
    "Federated conversation" : "Conversa federada",
    "Public conversation" : "Conversa pública",
    "Favorite" : "Favorito",
    "Banned users" : "Usuários banidos",
    "Manage the list of banned users in this conversation." : "Gerencie a lista de usuários banidos nesta conversa.",
    "Manage bans" : "Gerenciar banimentos",
    "No banned users" : "Nenhum usuário banido",
    "Banned by:" : "Banido por:",
    "Date:" : "Data:",
    "Note:" : "Anotação:",
    "Hide details" : "Ocultar detalhes",
    "Show details" : "Exibir detalhes",
    "Unban" : "Desbanir",
    "You can change the title and the description in {linkstart}Calendar ↗{linkend}." : "Você pode alterar o título e a descrição no {linkstart}Calendário ↗{linkend}.",
    "Error while updating conversation name" : "Erro ao atualizar o nome da conversa",
    "Error while updating conversation description" : "Ocorreu um erro ao editar a descrição da conversa",
    "Enter a name for this conversation" : "Digite um nome para esta conversa",
    "Edit conversation name" : "Editar o nome da conversa",
    "Edit conversation description" : "Editar descrição da conversa",
    "Enter a description for this conversation" : "Digite uma descrição para esta conversa ",
    "Picture" : "Imagem",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "Os seguintes bots podem ser ativados nesta conversa. Entre em contato com sua administração para obter mais bots instalados neste servidor.",
    "No bots are installed on this server. Reach out to your administration to get bots installed on this server." : "Nenhum bot está instalado neste servidor. Entre em contato com sua administração para instalar bots neste servidor.",
    "Disable" : "Desativar",
    "Enable" : "Ativar",
    "The bot is not available anymore" : "O robô não está mais disponível",
    "Breakout rooms" : "Salas temáticas",
    "Manage breakout rooms" : "Gerenciar salas temáticas",
    "Set up breakout rooms for this conversation" : "Criar salas temáticas para esta conversa",
    "Please select a valid PNG or JPG file" : "Por favor, selecione um arquivo PNG ou JPG válido",
    "Choose your conversation picture" : "Escolha sua imagem da conversa",
    "Choose" : "Escolher",
    "Error setting conversation picture" : "Erro ao configurar imagem da conversa",
    "Could not set the conversation picture: {error}" : "Não foi possível definir imagem da conversa: {error}",
    "Error cropping conversation picture" : "Erro ao cortar imagem da conversa",
    "Error removing conversation picture" : "Erro ao remover imagem da conversa",
    "Set emoji as conversation picture" : "Configurar emoji como imagem da conversa",
    "Set background color for conversation picture" : "Configurar cor do plano de fundo para imagem da conversa",
    "Upload conversation picture" : "Fazer upload da imagem da conversa",
    "Choose conversation picture from files" : "Escolher imagem da conversa a partir dos arquivos",
    "Remove conversation picture" : "Remover imagem da conversa",
    "The file must be a PNG or JPG" : "O arquivo deve ser um PNG ou JPG",
    "Set picture" : "Configurar imagem",
    "Default permissions modified for {conversationName}" : "Permissões padrão modificadas para {conversationName}",
    "Could not modify default permissions for {conversationName}" : "Não foi possível modificar as permissões padrão para {conversationName}",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Edite as permissões padrão para os participantes desta conversa. Essas configurações não afetam os moderadores.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Toda vez que as permissões são modificadas nesta seção, as permissões personalizadas anteriormente atribuídas a participantes individuais serão perdidas.",
    "All permissions" : "Todas as permissões",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "Os participantes têm permissão para iniciar uma chamada, entrar em uma chamada, ativar áudio e vídeo e compartilhar a tela.",
    "Participants can use all available features." : "Os participantes podem utilizar todos os recursos disponíveis.",
    "Restricted" : "Restritas",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Os participantes podem entrar em chamadas, mas não podem ativar áudio ou vídeo, nem compartilhar a tela até que um moderador lhes conceda as permissões manualmente.",
    "Participants get a reduced feature set until a moderator manually grants additional permissions." : "Os participantes têm acesso a um conjunto reduzido de recursos até que um moderador conceda manualmente permissões adicionais.",
    "Advanced permissions" : "Permissões avançadas",
    "Edit permissions" : "Editar permissões ",
    "Conversation settings" : "Configurações da conversa",
    "Basic Info" : "Informações Básicas",
    "Personal" : "Pessoal",
    "Moderation" : "Moderação",
    "Setup overview" : "Visão geral da configuração",
    "Live transcription" : "Transcrição em tempo real",
    "Live transcriptions app is not installed" : "O aplicativo de transcrição em tempo real não está instalado",
    "Enable live transcription" : "Ativar transcrição em tempo real",
    "Breakout Rooms" : "Salas Temáticas",
    "Matterbridge" : "Matterbridge",
    "Bots" : "Bots",
    "Danger zone" : "Zona de perigo",
    "Archive conversation" : "Arquivar conversa",
    "Archived conversations are hidden from the conversation list by default. However, they will still appear when you search for the conversation name or access a list of archived conversations." : "Conversas arquivadas são ocultadas da lista de conversas por padrão. No entanto, elas ainda aparecerão quando você pesquisar o nome da conversa ou acessar uma lista de conversas arquivadas.",
    "Do you really want to leave \"{displayName}\"?" : "Você realmente quer sair de \"{displayName}\"?",
    "You can archive this conversation instead." : "Em vez disso, você pode arquivar esta conversa.",
    "Leave conversation" : "Encerrar conversa",
    "You need to promote a new moderator before you can leave the conversation" : "Você precisa promover um novo moderador antes de sair da conversa",
    "Delete conversation" : "Excluir conversa",
    "Do you really want to delete \"{displayName}\"?" : "Você realmente quer excluir \"{displayName}\"?",
    "Error while deleting conversation" : "Erro ao excluir a conversa",
    "Delete all chat messages" : "Excluir todas as mensagens de bate-papo ",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Você realmente quer excluir todas as mensagens em \"{displayName}\"?",
    "Error while clearing chat history" : "Erro ao limpar o histórico de bate-papo ",
    "Be careful, these actions cannot be undone." : "Cuidado, estas ações não podem ser desfeitas.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Depois que uma conversa é encerrada, para voltar a uma conversa encerrada, é necessário um convite. Uma conversa aberta pode ser retomada a qualquer momento. ",
    "Permanently delete this conversation." : "Excluir esta conversa permanentemente. ",
    "Delete chat messages" : "Excluir mensagens de bate-papo ",
    "Permanently delete all the messages in this conversation." : "Excluir permanentemente todas as mensagens desta conversa. ",
    "_%n hour_::_%n hours_" : ["%n hora","%n horas","%n horas"],
    "_%n day_::_%n days_" : ["%n dia","%n dias","%n dias"],
    "_%n week_::_%n weeks_" : ["%n semana","%n semanas","%n semanas"],
    "Custom expiration time" : "Tempo de expiração personalizado",
    "Message expiration disabled" : "Expiração de mensagens desativada",
    "Message expiration set: {duration}" : "Expiração de mensagens configurada: {duration}",
    "Error when trying to set message expiration" : "Erro ao tentar definir a expiração de mensagens",
    "Message expiration" : "Expiração de mensagens",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "As mensagens de bate-papo podem expirar após um certo tempo. Observação: Os arquivos compartilhados no bate-papo não serão excluídos para o proprietário, mas não serão mais compartilhados na conversa.",
    "Set message expiration" : "Definir expiração de mensagens",
    "Current message expiration" : "Expiração de mensagens atual",
    "Password copied to clipboard" : "Senha copiada para a área de transferência",
    "Password could not be copied" : "Não foi possível copiar a senha",
    "Guest access" : "Acesso para convidados",
    "Breakout rooms are not allowed in public conversations." : "Salas temáticas não são permitidas em conversas públicas.",
    "Allow guests to join this conversation via link" : "Permitir que os convidados entrem nesta conversa por meio de um link",
    "Password protection" : "Proteção por senha",
    "This conversation is password-protected. Guests need password to join" : "Esta conversa é protegida por senha. Os convidados precisam de senha para participar",
    "Password protection is needed for public conversations" : "A proteção por senha é necessária para conversas públicas",
    "Set a password" : "Definir uma senha",
    "Change password" : "Alterar senha",
    "Enter new password" : "Insira a nova senha",
    "Save password" : "Salvar senha",
    "Copy password" : "Copiar a senha",
    "Guests are allowed to join this conversation via link" : "Convidados têm permissão para entrar nesta conversa por meio de um link",
    "Guests are not allowed to join this conversation" : "Convidados não têm permissão para entrar nesta conversa",
    "Resend invitations" : "Reenviar convites",
    "This conversation is open to both registered users and users created with the Guests app" : "Esta conversa está aberta tanto para usuários registrados quanto para usuários criados com o aplicativo Convidados",
    "This conversation is open to registered users" : "Esta conversa está aberta a usuários registrados",
    "This conversation is limited to the current participants" : "Esta conversa é limitada aos participantes atuais",
    "You opened the conversation to both registered users and users created with the Guests app" : "Você abriu a conversa para usuários registrados e usuários criados com o aplicativo Convidados",
    "Error occurred when opening or limiting the conversation" : "Ocorreu um erro ao abrir ou limitar a conversa",
    "Open conversation to registered users, showing it in search results" : "Abrir a conversa para usuários registrados, mostrando-a nos resultados da pesquisa",
    "Also open to users created with the Guests app" : "Também abrir para usuários criados com o aplicativo Convidados",
    "Open conversation" : "Abrir conversa",
    "Set language spoken in calls" : "Definir idioma falado nas chamadas",
    "Languages could not be loaded" : "Não foi possível carregar os idiomas",
    "Loading languages …" : "Carregando idiomas …",
    "Invalid language" : "Idioma inválido",
    "Default language (English)" : "Idioma padrão (inglês)",
    "Default live transcription language set" : "Idioma padrão definido para transcrição em tempo real",
    "Live transcription language set: {languageName}" : "Idioma definido para transcrição em tempo real: {languageName}",
    "Error when trying to set live transcription language" : "Erro ao definir o idioma para transcrição em tempo real",
    "Start time: {date}" : "Hora de início: {date}",
    "Start time has been updated" : "A hora de início foi atualizada",
    "Error occurred while updating start time" : "Ocorreu um erro ao atualizar a hora de início",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "Ativar a sala de espera removerá os não moderadores da chamada em andamento.",
    "Enable lobby, restricting the conversation to moderators" : "Ativar sala de espera, restringindo a conversa aos moderadores",
    "Meeting start time" : "Hora de início da reunião",
    "Start time (optional)" : "Horário de início (opcional)",
    "Import email participants" : "Importar e-mail dos participantes",
    "You can import a list of email participants from a CSV file." : "Você pode importar uma lista de participantes de e-mail de um arquivo CSV.",
    "Poll drafts" : "Rascunhos de enquetes",
    "Browse poll drafts" : "Navegar pelos rascunhos de enquetes",
    "Error occurred when locking the conversation" : "Ocorreu um erro ao trancar a conversa",
    "Error occurred when unlocking the conversation" : "Ocorreu um erro ao destrancar a conversa",
    "Lock conversation" : "Trancar conversa",
    "This will also terminate the ongoing call." : "Isso também encerrará a chamada em andamento. ",
    "Lock the conversation to prevent anyone to post messages or start calls" : "Tranque a conversa para impedir que alguém poste mensagens ou inicie chamadas",
    "Edit" : "Editar",
    "More information" : "Mais informações",
    "Delete" : "Excluir",
    "Add new bridged channel to current conversation" : "Adicionar novo canal de comunicação para a conversa atual",
    "unknown state" : "estado desconhecido",
    "running" : "rodando",
    "not running, check Matterbridge log" : "não está funcionando, verifique o log do Matterbridge",
    "not running" : "sem funcionamento",
    "Bridge saved" : "Ponte salva",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "Você pode conectar canais de vários sistemas de mensagens instantâneas com Matterbridge.",
    "More info on Matterbridge" : "Mais informações no Matterbridge",
    "Messaging systems" : "Sistemas de mensagens",
    "Enable bridge" : "Ativar ponte",
    "Show Matterbridge log" : "Mostrar log do Matterbridge",
    "Log content" : "Conteúdo do registro",
    "Only moderators are allowed to mention @all" : "Somente moderadores podem mencionar @all",
    "All participants are allowed to mention @all" : "Todos os participantes podem mencionar @all",
    "Participants are now allowed to mention @all." : "Os participantes agora podem mencionar @all.",
    "Mentioning @all has been limited to moderators." : "Mencionar @all foi limitado aos moderadores.",
    "Allow participants to mention @all" : "Permitir que os participantes mencionem @all",
    "Mention permissions" : "Permissões de menção",
    "Notifications" : "Notificações",
    "Notify about calls in this conversation" : "Notificar sobre chamadas nesta conversa ",
    "Important conversation" : "Conversa importante",
    "\"Do not disturb\" user status is ignored for important conversations" : "O status de usuário \"Não perturbe\" é ignorado em conversas importantes",
    "Sensitive conversation" : "Conversa sensível",
    "Message preview will be disabled in conversation list and notifications" : "A visualização de mensagens será desativada na lista de conversas e nas notificações",
    "Recording consent is required for calls in this conversation" : "O consentimento de gravação é necessário para chamadas nesta conversa",
    "Recording consent is not required for calls in this conversation" : "O consentimento de gravação não é necessário para chamadas nesta conversa",
    "Recording consent requirement was updated" : "O requisito de consentimento de gravação foi atualizado",
    "Error occurred while updating recording consent" : "Ocorreu um erro ao atualizar o consentimento de gravação",
    "Recording Consent" : "Consentimento de Gravação",
    "Recording consent cannot be changed once a call or breakout session has started." : "O consentimento de gravação não pode ser alterado após o início de uma chamada ou sessão de sala temática.",
    "Require recording consent before joining call in this conversation" : "Exigir consentimento de gravação antes de entrar em uma chamada nesta conversa",
    "Recording consent is required for all calls" : "O consentimento de gravação é necessário para todas as chamadas",
    "SIP dial-in is now possible without PIN requirement" : "A discagem SIP agora é possível sem a necessidade de PIN",
    "SIP dial-in is now enabled" : "A discagem SIP agora está ativada",
    "SIP dial-in is now disabled" : "A discagem SIP agora está desativada",
    "Error occurred when enabling SIP dial-in" : "Ocorreu um erro ao ativar a discagem SIP",
    "Error occurred when disabling SIP dial-in" : "Ocorreu um erro ao desativar a discagem SIP",
    "Phone and SIP dial-in" : "Discagem por telefone e SIP",
    "Enable phone and SIP dial-in" : "Ativar discagem por telefone e SIP",
    "Allow to dial-in without a PIN" : "Permitir discar sem um PIN",
    "Ongoing" : "Em andamento",
    "{dayPrefix} {dateTime}" : "{dayPrefix} {dateTime}",
    "_%n person accepted_::_%n people accepted_" : ["%n pessoa aceitou","%n pessoas aceitaram","%n pessoas aceitaram"],
    "_%n person declined_::_%n people declined_" : ["%n pessoa recusou","%n pessoas recusaram","%n pessoas recusaram"],
    "_and %n other attachment_::_and %n other attachments_" : ["e %n outro anexo","e %n de outros anexos","e %n outros anexos"],
    "With {displayName}" : "Com {displayName}",
    "In {conversation}" : "Em {conversation}",
    "View attachment" : "Exibir anexo",
    "Join" : "Entrar",
    "View conversation" : "Exibir conversa",
    "View event on Calendar" : "Exibir evento no Calendário",
    "Error while creating the conversation" : "Erro ao criar a conversa",
    "Hello, {displayName}" : "Olá, {displayName}",
    "Start meeting now" : "Iniciar reunião agora",
    "Give your meeting a title" : "Dê um título à sua reunião",
    "Create and copy link" : "Criar e copiar link",
    "Create a new conversation" : "Criar uma nova conversa",
    "Join open conversations" : "Entrar em conversas abertas",
    "Call a phone number" : "Ligar para um número de telefone",
    "Scroll backward" : "Rolar para trás",
    "Scroll forward" : "Rolar para frente",
    "Schedule meetings" : "Agendar reuniões",
    "You don't have any upcoming meetings" : "Você não tem nenhuma reunião em breve.",
    "Calendar events with a conversation link as the location are shown here" : "Os eventos do calendário cujo local é um link de conversa são exibidos aqui",
    "Open calendar" : "Abrir calendário",
    "Unread mentions" : "Menções não lidas",
    "Messages where you were mentioned will show up here. You can mention people by typing @ followed by their name" : "As mensagens em que você foi mencionado aparecerão aqui. Você pode mencionar pessoas digitando @ seguido do nome delas.",
    "Upcoming reminders" : "Próximos lembretes",
    "Message reminders" : "Lembretes de mensagens",
    "Set a reminder on a message to be notified" : "Defina um lembrete em uma mensagem para ser notificado",
    "Start a group conversation" : "Iniciar conversa de grupo",
    "Create conversation" : "Criando conversa",
    "Enter your name" : "Digite seu nome",
    "Submit name and join" : "Envie o nome e entre",
    "Do you already have an account?" : "Você já tem uma conta?",
    "Log in" : "Login",
    "Error while verifying uploaded file" : "Erro ao verificar o arquivo carregado",
    "Uploaded file is verified" : "O arquivo carregado foi verificado",
    "Content format is comma-separated values (CSV):<br/>- Header line is required and must match <samp>\"name\",\"email\"</samp> or just <samp>\"email\"</samp><br/>- One entry per line (e.g. <samp>\"John Doe\",\"john@example.tld\"</samp>)" : "O formato do conteúdo é valores separados por vírgula (CSV):<br/>- A linha do cabeçalho é obrigatória e deve corresponder a <samp>\"name\",\"email\"</samp> ou apenas <samp>\"email\"</samp><br/>- Uma entrada por linha (p. ex., <samp>\"João da Silva\",\"joao@example.tld\"</samp>)",
    "Participants added successfully" : "Participantes adicionados com sucesso",
    "Error while adding participants" : "Erro ao adicionar participantes",
    "Import a file" : "Importar um arquivo",
    "Browse" : "Navegar",
    "Verifying uploaded file …" : "Verificando arquivo carregado …",
    "This might take a moment" : "Isso pode demorar um pouco",
    "Send invitations" : "Enviar convites",
    "_%n invalid email_::_%n invalid emails_" : ["%n e-mail inválido","%n e-mails inválidos","%n e-mails inválidos"],
    "_%n email is already imported or a duplicate_::_%n emails are already imported or duplicates_" : ["%n e-mail já foi importado ou duplicado","%n e-mails já foram importados ou duplicados","%n e-mails já foram importados ou duplicados"],
    "_%n invitation can be sent_::_%n invitations can be sent_" : ["%n convite pode ser enviado","%n convites podem ser enviados","%n convites podem ser enviados"],
    "An error occurred while calling a phone number" : "Ocorreu um erro ao ligar para um número de telefone",
    "Phone number could not be called: {error}" : "Não foi possível ligar para o número de telefone: {error}",
    "Phone number could not be called" : "Não foi possível ligar para o número de telefone",
    "Search participants or phone numbers" : "Pesquisar participantes ou números de telefone",
    "Creating the conversation …" : "Criando a conversa …",
    "Mark as read" : "Marcar como lido ",
    "Mark as unread" : "Marcar como não lido",
    "Remove from favorites" : "Remover dos favoritos",
    "Add to favorites" : "Adicionar aos favoritos",
    "Unarchive conversation" : "Desarquivar conversa",
    "Ignore \"Do not disturb\"" : "Ignorar \"Não perturbe\"",
    "You need to promote a new moderator before you can leave the conversation." : "Você precisa promover um novo moderador antes de sair da conversa.",
    "Conversation actions" : "Ações de conversa",
    "Notify about calls" : "Notificar sobre chamadas",
    "Hide message text" : "Ocultar texto da mensagem",
    "Pending invitations" : "Convites pendentes",
    "Join conversations from other servers" : "Entrar nas conversas de outros servidores",
    "From {user} at {remoteServer}" : "De {user} em {remoteServer}",
    "Decline invitation" : "Recusar convite",
    "Accept invitation" : "Aceitar convite",
    "No pending invitations" : "Nenhum convite pendente",
    "Home" : "Início",
    "Unread" : "Não lido",
    "Mentions" : "Menções",
    "Meetings" : "Reuniões",
    "Sort conversations" : "Ordenar conversas",
    "By recent activity" : "Por atividade recente",
    "Alphabetically" : "Alfabeticamente",
    "Do not group by type" : "Não agrupar por tipo",
    "Show private ones first" : "Mostrar primeiro as privadas",
    "Show group ones first" : "Mostrar primeiro as agrupadas",
    "No followed threads" : "Sem fios seguidos",
    "No matches found" : "Nenhuma correspondência encontrada",
    "No conversations found" : "Nenhuma conversa encontrada",
    "You have no archived conversations." : "Você não tem conversas arquivadas",
    "Subscribe to an existing thread or start your own." : "Assine um fio já existente ou inicie o seu próprio.",
    "You have no unread mentions." : "Você não tem menções não lidas.",
    "You have no unread messages." : "Você não tem mensagens não lidas.",
    "An error occurred while performing the search" : "Erro ao pesquisar",
    "Conversation list" : "Lista de conversas",
    "Filter conversations by" : "Filtrar conversa por",
    "Unread messages" : "Mensagens não lidas",
    "Meeting conversations" : "Conversas de reuniões",
    "Clear filters" : "Limpar filtros",
    "New personal note" : "Nova nota pessoal",
    "SIP backend is not installed" : "O back-end SIP não está instalado",
    "Back to conversations" : "Voltar às conversas",
    "Archived conversations" : "Conversas arquivadas",
    "Threads" : "Fios",
    "Clear filter" : "Limpar filtro",
    "Show more threads" : "Mostrar mais fios",
    "App settings" : "Configurações do aplicativo",
    "Users" : "Usuários",
    "Groups" : "Grupos",
    "Teams" : "Equipes",
    "Federated users" : "Usuários federados",
    "New private conversation" : "Nova conversa privada",
    "Other sources" : "Outras fontes",
    "Open conversations" : "Abrir conversas",
    "No search results" : "Nenhum resultado encontrado",
    "Users, groups and teams" : "Usuários, grupos e equipes",
    "Users and groups" : "Usuários e grupos",
    "Users and teams" : "Usuários e equipes",
    "Groups and teams" : "Grupos e equipes",
    "New group conversation" : "Nova conversa em grupo",
    "The meeting will start soon" : "A reunião iniciará em breve",
    "This meeting is scheduled for {startTime}" : "Esta reunião está agendada para iniciar em {startTime}",
    "You are currently waiting in the lobby" : "Você está atualmente esperando na sala de espera",
    "Enable noise suppression" : "Ativar supressão de ruído",
    "Reduce background noises for better voice quality" : "Reduza os ruídos de fundo para obter uma melhor qualidade de voz",
    "Enable echo cancellation" : "Ativar cancelamento de eco",
    "Minimize echo effect from own surrounding" : "Minimize o efeito de eco do próprio ambiente",
    "Enable auto gain control" : "Ativar controle automático de ganho",
    "Dynamically adjust microphone volume for consistent level" : "Ajuste dinamicamente o volume do microfone para obter um nível consistente",
    "Select microphone" : "Selecionar microfone",
    "No microphone available" : "Nenhum microfone disponível",
    "Select speaker" : "Selecionar alto-falante",
    "No speaker available" : "Nenhum alto-falante disponível",
    "Select camera" : "Selecionar câmera",
    "No camera available" : "Nenhuma câmera disponível",
    "Select a device" : "Selecionar um dispositivo",
    "Playing …" : "Reproduzindo …",
    "Test speakers" : "Testar alto-falantes",
    "Test" : "Teste",
    "Devices" : "Dispositivos",
    "Backgrounds" : "Planos de Fundo",
    "No audio" : "Sem áudio",
    "No camera" : "Sem câmera",
    "Display video as you will see it (mirrored)" : "Exibir vídeo como você o verá (espelhado)",
    "Display video as others will see it" : "Exibir vídeo como os outros o verão",
    "Calls are not supported in your browser" : "Seu navegador não suporta chamadas",
    "Access to microphone is only possible with HTTPS" : "O acesso ao microfone somente é possível via HTTPS",
    "Access to microphone was denied" : "O acesso ao microfone foi negado",
    "Error while accessing microphone" : "Erro ao acessar microfone",
    "Access to camera is only possible with HTTPS" : "O acesso à câmera somente é possível via HTTPS",
    "The call is being recorded." : "A chamada está sendo gravada.",
    "The call might be recorded." : "A chamada pode ser gravada.",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "A gravação pode incluir sua voz, vídeo da câmera e compartilhamento de tela. Seu consentimento é necessário antes de entrar na chamada.",
    "Give consent to the recording of this call" : "Dê consentimento para a gravação desta chamada",
    "Show more info" : "Mostrar mais informações",
    "Audio is not available" : "Áudio não está disponível",
    "Video is not available" : "Vídeo não está disponível",
    "Start recording immediately with the call" : "Iniciar a gravação imediatamente com a chamada",
    "Recording backend is not installed" : "O back-end de gravação não está instalado",
    "Notify all participants about this call" : "Notificar todos os participantes sobre esta chamada",
    "Apply settings" : "Aplicar configurações",
    "Select virtual office background" : "Selecionar o plano de fundo de escritório virtual",
    "Select virtual home background" : "Selecionar o plano de fundo de casa virtual",
    "Select virtual abstract background" : "Selecione o plano de fundo abstrato virtual",
    "Select virtual beach background" : "Selecione o plano do fundo de praia virtual",
    "Select virtual park background" : "Selecione o plano de fundo de parque virtual",
    "Select virtual theater background" : "Selecionar o plano de fundo de teatro virtual",
    "Select virtual library background" : "Selecione o plano de fundo de biblioteca virtual",
    "Select virtual space station background" : "Selecionar o plano de fundo de estação espacial virtual",
    "Error while uploading the file" : "Erro no upload do arquivo",
    "Select a file" : "Selecionar um arquivo",
    "Invalid path selected" : "Caminho inválido selecionado",
    "Select virtual background from file {fileName}" : "Selecionar o plano de fundo virtual do arquivo {fileName}",
    "Blur" : "Desfocar",
    "Upload" : "Carregar",
    "Files" : "Arquivos",
    "(editing)" : "(editando)",
    "(edited)" : "(editado)",
    "The message has expired or has been deleted" : "A mensagem expirou ou foi excluída",
    "Cancel quote" : "Cancelar citação",
    "24 hours" : "24 horas",
    "7 days" : "7 dias",
    "30 days" : "30 dias",
    "Until unpin" : "Até desfixar",
    "Clear reminder – {timeLocale}" : "Limpar lembrete – {timeLocale}",
    "Edited by {actor}" : "Editado por {actor}",
    "Pinned by you" : "Fixada por você",
    "Pinned by {actor}" : "Fixada por {actor}",
    "Until {absoluteDate}" : "Até {absoluteDate}",
    "Message text copied to clipboard" : "Texto da mensagem copiado para a área de transferência",
    "Message text could not be copied" : "Não foi possível copiar o texto da mensagem",
    "Message forwarded to \"Note to self\"" : "Mensagem encaminhada para \"Nota para si mesmo\"",
    "Error while forwarding message to \"Note to self\"" : "Erro ao encaminhar mensagem para \"Nota para si mesmo\"",
    "A reminder was successfully removed" : "Um lembrete foi removido com sucesso",
    "Error occurred when removing a reminder" : "Ocorreu um erro ao remover um lembrete",
    "A reminder was successfully set at {datetime}" : "Um lembrete foi definido com sucesso em {datetime}",
    "Error occurred when creating a reminder" : "Ocorreu um erro ao criar um lembrete",
    "Add a reaction to this message" : "Adicionar uma reação a esta mensagem",
    "Reply" : "Responder",
    "More actions" : "Mais ações",
    "Set reminder" : "Definir lembrete",
    "Pin message" : "Fixar mensagem",
    "Unpin message" : "Desfixar mensagem",
    "Reply privately" : "Responda em particular",
    "Edit message" : "Editar mensagem",
    "Copy message" : "Copiar mensagem",
    "Copy message link" : "Copiar link da mensagem",
    "Go to file" : "Ir para o arquivo",
    "Download file" : "Baixar arquivo",
    "Go to thread" : "Ir para fio",
    "Edit thread details" : "Editar detalhes do fio",
    "Forward message" : "Encaminhar mensagem",
    "Translate" : "Traduzir",
    "Set custom reminder" : "Definir lembrete personalizado",
    "Keep pinned for" : "Manter fixada para",
    "Set custom period" : "Definir período personalizado",
    "Close reactions menu" : "Fechar menu de reações",
    "React with {emoji}" : "Reagir com {emoji}",
    "React with another emoji" : "Reagir com outro emoji",
    "Choose a conversation to forward the selected message." : "Escolha uma conversa para encaminhar a mensagem selecionada. ",
    "Error while forwarding message" : "Erro ao encaminhar mensagem ",
    "The message has been forwarded to {selectedConversationName}" : "A mensagem foi encaminhada para {selectedConversationName}",
    "Dismiss" : "Dispensar",
    "Go to conversation" : "Ir para a conversa ",
    "Detect language" : "Detectar idioma",
    "The message could not be translated" : "A mensagem não pôde ser traduzida",
    "Translation copied to clipboard" : "Tradução copiada para a área de transferência",
    "Translation could not be copied" : "A tradução não pôde ser copiada",
    "Translate message" : "Traduzir mensagem",
    "Source language to translate from" : "Idioma de origem do qual traduzir",
    "Translate from" : "Traduzir de",
    "Target language to translate into" : "Idioma de destino para o qual traduzir",
    "Translate to" : "Traduzir para",
    "Translating" : "Traduzindo",
    "This translation is AI generated and may contain mistakes." : "Esta tradução foi gerada por IA e pode conter erros.",
    "Copy translated text" : "Copiar texto traduzido",
    "Error when scheduling the message" : "Erro ao agendar a mensagem",
    "Reschedule" : "Reagendar",
    "Send now" : "Enviar agora",
    "Choose a time" : "Escolha um horário",
    "Send at custom time" : "Enviar em horário personalizado",
    "Will be sent without notification" : "Será enviada sem notificação",
    "Message read by everyone who shares their reading status" : "Mensagem lida por todos que compartilham seu status de leitura",
    "Message sent" : "Mensagem enviada",
    "Sent without notification" : "Enviada sem notificação",
    "Deleting message" : "Excluindo mensagem",
    "Message deleted successfully, but a bot or Matterbridge is configured and the message might already be distributed to other services" : "Mensagem excluída com êxito, mas um bot ou Matterbridge está configurado e a mensagem pode já estar distribuída para outros serviços",
    "Message deleted successfully" : "Mensagem excluída com sucesso",
    "Message could not be deleted because it is too old" : "A mensagem não pôde ser excluída porque é muito antiga",
    "Only normal chat messages can be deleted" : "Apenas mensagens normais de bate-papo podem ser excluídas",
    "An error occurred while deleting the message" : "Ocorreu um erro ao excluir a mensagem",
    "Pinned" : "Fixada",
    "Your browser does not support playing audio files" : "Seu navegador não suporta a reprodução de arquivos de áudio",
    "Contact" : "Contato",
    "{stack} in {board}" : "{stack} de {board}",
    "Deck Card" : "Cartão Deck",
    "Remove {fileName}" : "Remover {fileName} ",
    "Open this location in OpenStreetMap" : "Abrir este local no OpenStreetMap",
    "_%n reply_::_%n replies_" : ["%n resposta","%n de respostas","%n respostas"],
    "Sending message" : "Enviando mensagem",
    "Failed to send the message. Click to try again" : "Ocorreu um erro ao enviar a mensagem. Clique para tentar novamente.",
    "Not enough free space to upload file" : "Espaço livre insuficiente para enviar o arquivo",
    "You cannot send messages to this conversation at the moment" : "No momento, você não pode enviar mensagens para esta conversa",
    "Could not update the message" : "Não foi possível atualizar a mensagem",
    "Reply to thread \"{threadTitle}\"" : "Responder ao fio \"{threadTitle}\"",
    "_You voted • %n vote_::_You voted • %n votes_" : ["Você votou • %n voto","Você votou • %n de votos","Você votou • %n votos"],
    "You voted" : "Você votou",
    "_Click to vote • %n vote_::_Click to vote • %n votes_" : ["Clique para votar • %n voto","Clique para votar • %n de votos","Clique para votar • %n votos"],
    "Click to vote" : "Clique para votar",
    "_Poll draft • %n option_::_Poll draft • %n options_" : ["Rascunho de enquete • %n opção","Rascunho de enquete • %n opções","Rascunho de enquete • %n opções"],
    "_%n vote_::_%n votes_" : ["%n voto","%n de votos","%n votos"],
    "Edit poll draft" : "Editar o rascunho da enquete",
    "Delete poll draft" : "Excluir o rascunho da enquete",
    "Open poll" : "Enquete aberta",
    "Closed poll" : "Enquete encerrada",
    "See results" : "Ver resultados",
    "Reactions" : "Reações",
    "No permission to post reactions in this conversation" : "Sem permissão para postar reações nesta conversa",
    "and {participant}" : "e {participant}",
    "_and %n other participant_::_and %n other participants_" : ["e %n outro participante","e %n outros participantes","e %n outros participantes"],
    "Show all reactions" : "Mostrar todas as reações",
    "Add more reactions" : "Adicionar mais reações",
    "Show or collapse system messages" : "Mostrar ou recolher mensagens do sistema",
    "No messages" : "Sem mensagens",
    "All messages have expired or have been deleted." : "Todas as mensagens expiraram ou foram excluídas.",
    "Generate summary with AI" : "Gerar resumo com IA",
    "{author} (pinned by you)" : "{author} (fixada por você)",
    "{author} (pinned by {actor})" : "{author} (fixada por {actor})",
    "Unpin" : "Desfixar",
    "Cancel search" : "Cancelar pesquisa",
    "Add a phone number" : "Adicionar um número de telefone",
    "Error: A password is required to create the conversation." : "Erro: É necessária uma senha para criar a conversa.",
    "All set, the conversation \"{conversationName}\" was created." : "Tudo pronto, a conversa \"{conversationName}\" foi criada.",
    "Create a new group conversation" : "Criar um novo grupo de conversa",
    "Add participants" : "Adicionar participantes",
    "Maximum length exceeded ({maxlength} characters)" : "Comprimento máximo excedido ({maxlength} caracteres)",
    "Conversation type" : "Tipo de conversa",
    "Conversation visibility" : "Visibilidade da conversa",
    "Allow guests to join via link" : "Permitir que convidados participem via link",
    "Enter password" : "Digite a senha ",
    "This conversation has been locked" : "Esta conversa foi trancada",
    "No permission to post messages in this conversation" : "Sem permissão para postar mensagens nesta conversa",
    "Joining conversation …" : "Entrando na conversa...",
    "Write a message without notification" : "Escreva uma mensagem sem notificação",
    "Create a thread silently" : "Criar um fio silenciosamente",
    "Create a thread" : "Criar um fio",
    "Send message silently" : "Enviar mensagem silenciosamente",
    "Send message" : "Enviar mensagem",
    "Send without notification" : "Enviar sem notificação",
    "The participant will not be notified about new messages" : "O participante não será notificado sobre novas mensagens",
    "Participants will not be notified about new messages" : "Participantes não serão notificados sobre novas mensagens",
    "Message will be sent {datetimeString}" : "A mensagem será enviada em {datetimeString}",
    "Thread title is required" : "O título do fio é obrigatório",
    "Message text is required" : "O texto da mensagem é obrigatório",
    "The message could not be edited" : "A mensagem não pôde ser editada",
    "File to share" : "Arquivo a compartilhar",
    "File upload is not available in this conversation" : "O upload de arquivo não está disponível nesta conversa",
    "Message was successfully scheduled" : "A mensagem foi agendada com êxito",
    "Add emoji" : "Adicionar emoji",
    "Adding a mention will only notify users who did not read the message." : "Adicionar uma menção notificará apenas os usuários que não leram a mensagem.",
    "Thread title" : "Título do fio",
    "Send later" : "Enviar mais tarde",
    "Show scheduled messages" : "Mostrar mensagens agendadas",
    "Cancel editing" : "Cancelar edição",
    "Schedule message" : "Agendar mensagem",
    "{user} is out of office and might not respond." : "{user}está fora do escritório e talvez não responda.",
    "Absence period: {startDate} - {endDate}" : "Período de ausência: {startDate} - {endDate}",
    "Replacement:" : "Subsituto:",
    "Share from {nextcloud}" : "Compartilhar de {nextcloud}",
    "Share from Files" : "Compartilhar de Arquivos",
    "Share files to the conversation" : "Compartilhar arquivos na conversa",
    "Upload from device" : "Fazer upload do dispositivo",
    "Create new poll" : "Criar nova enquete",
    "Smart picker" : "Seletor inteligente",
    "Record voice message" : "Gravar mensagem de voz",
    "End recording and send" : "Terminar a gravação e enviar",
    "Dismiss recording" : "Dispensar gravação",
    "Access to the microphone was denied" : "Acesso ao microfone foi negado",
    "Microphone either not available or disabled in settings" : "Microfone ou não disponível ou está desativado nas configurações",
    "Error while recording audio" : "Erro ao gravar áudio",
    "Voice message {time} ({conversation})" : "Mensagem de voz {time} ({conversation})",
    "Generating summary of unread messages …" : "Geração de resumo de mensagens não lidas …",
    "Summary is AI generated and might contain mistakes" : "O resumo é gerado por IA e pode conter erros",
    "Error occurred during a summary generation" : "Ocorreu um erro durante a geração de um resumo",
    "New file" : "Novo arquivo",
    "Blank" : "Vazio",
    "Error while creating file" : "Erro ao criar arquivo",
    "Create and share a new file" : "Criar e compartilhar um novo arquivo",
    "Name of the new file" : "Nome do novo arquivo",
    "Create file" : "Criar arquivo",
    "Someone is typing …" : "Alguém está digitando …",
    "{user1} is typing …" : "{user1} está digitando …",
    "{user1} and {user2} are typing …" : "{user1} e {user2} estão digitando …",
    "{user1}, {user2} and {user3} are typing …" : "{user1}, {user2} e {user3} estão digitando …",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2}, {user3} e %n outro estão digitando …","{user1}, {user2}, {user3} e %n outros estão digitando …","{user1}, {user2}, {user3} e %n outros estão digitando …"],
    "Add more files" : "Adicionar mais arquivos",
    "Send" : "Enviar",
    "In this conversation <strong>{user}</strong> can:" : "Nesta conversa, <strong>{user}</strong> pode:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Editar permissões padrão para participantes em <strong>{conversationName}</strong>",
    "Start a call" : "Iniciar uma chamada",
    "Skip the lobby" : "Pular a sala de espera",
    "Can post messages" : "Pode postar mensagens",
    "Can post messages and reactions" : "Postar mensagens e reações",
    "Can add reactions" : "Pode adicionar reações",
    "Enable the microphone" : "Ativar o microfone",
    "Enable the camera" : "Ativar a câmera",
    "Share the screen" : "Compartilhar a tela ",
    "Update permissions" : "Atualizar permissões",
    "Updating permissions" : "Atualizando permissões",
    "No poll drafts" : "Sem rascunhos de enquetes",
    "There is no poll drafts yet saved for this conversation" : "Ainda não há rascunhos de enquete salvos para esta conversa",
    "Create poll in {name}" : "Criar enquete em {name}",
    "Create poll" : "Criar enquete",
    "Error while importing poll" : "Erro ao importar enquete",
    "Question" : "Pergunta",
    "Ask a question" : "Faça uma pergunta",
    "Import draft from file" : "Importar rascunho do arquivo",
    "Answers" : "Respostas",
    "Answer {option}" : "Resposta {option}",
    "Delete poll option" : "Excluir opção de enquete",
    "Add answer" : "Adicionar resposta",
    "Settings" : "Configurações",
    "Anonymous poll" : "Enquete anônima",
    "Multiple answers" : "Respostas múltiplas",
    "Save as draft" : "Salvar como rascunho",
    "Export draft to file" : "Exportar rascunho para arquivo",
    "_Final results • %n vote_::_Final results • %n votes_" : ["Resultados finais • %n voto","Resultados finais • %n de votos","Resultados finais • %n votos"],
    "Your vote is anonymous" : "Seu voto é anônimo",
    "You voted for this option" : "Você votou nesta opção",
    "End poll" : "Encerrar enquete",
    "Change your vote" : "Alterar seu voto",
    "Withdraw vote" : "Retirar voto",
    "Results" : "Resultados",
    "Voted participants" : "Participantes votantes",
    "Send a message to \"{roomName}\"" : "Enviar uma mensagem para \"{roomName}\"",
    "Hide list of participants" : "Ocultar lista de participantes",
    "Show list of participants" : "Exibir lista de participantes",
    "Assistance requested in {roomName}" : "Assistência solicitada em {roomName}",
    "The message was sent to \"{roomName}\"" : "A mensagem foi enviada para \"{roomName}\"",
    "Dismiss request for assistance" : "Dispensar pedido de assistência",
    "Send message to room" : "Enviar mensagem para sala",
    "Back to main room" : "Voltar à sala principal",
    "Back to your room" : "Voltar à sua sala",
    "Message all rooms" : "Mensagem para todas as salas",
    "Start session" : "Iniciar sessão",
    "Start a call before you start a breakout room session" : "Inicie uma chamada antes de você iniciar uma sessão de sala temática",
    "Stop session" : "Encerrar sessão",
    "The message was sent to all breakout rooms" : "A mensagem foi enviada para todas as salas temáticas",
    "Send a message to all breakout rooms" : "Enviar uma mensagem para todas as salas temáticas",
    "Breakout rooms are not started" : "As salas temáticas não foram iniciadas.",
    "Calls without High-performance backend can cause connectivity issues and high load on devices. {linkstart}Learn more{linkend}" : "Chamadas sem back-end de alto desempenho podem causar problemas de conectividade e alta carga nos dispositivos. {linkstart}Saiba mais{linkend}",
    "Talk setup incomplete" : "Configuração do Talk incompleta",
    "Disable lobby" : "Desativar sala de espera",
    "Settings for participant \"{user}\"" : "Configurações para o participante \"{user}\"",
    "Participant \"{user}\"" : "Participante \"{user}\"",
    "moderator" : "moderador",
    "bot" : "bot",
    "guest" : "convidado",
    "Ringing …" : "Tocando …",
    "Call rejected" : "Chamada rejeitada",
    "{time} talking …" : "Conversando por {time} …",
    "{time} talking time" : "{time} de tempo de conversa",
    "Raised their hand" : "Levantou a mão",
    "Joined with video" : "Entrou com video",
    "Joined via phone" : "Entrou via telefone",
    "Joined with audio" : "Entrou com áudio",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "O texto deve ter menos ou igual a {maxLength} caracteres. Seu texto atual tem {charactersCount} caracteres.",
    "Remove group and members" : "Remover grupo e membros",
    "Remove team and members" : "Remover equipe e membros",
    "Remove participant" : "Remover participante",
    "Do you really want to remove group \"{displayName}\" and its members from this conversation?" : "Você realmente deseja remover o grupo \"{displayName}\" e seus membros desta conversa?",
    "Do you really want to remove team \"{displayName}\" and its members from this conversation?" : "Você realmente deseja remover a equipe \"{displayName}\" e seus membros desta conversa?",
    "Do you really want to remove {displayName} from this conversation?" : "Você realmente deseja remover {displayName} desta conversa?",
    "Notification was sent to {displayName}" : "A notificação foi enviada para {displayName}",
    "Could not send notification to {displayName}" : "Não foi possível enviar a notificação para {displayName}",
    "Permissions granted to {displayName}" : "Permissões concedidas a {displayName} ",
    "Could not modify permissions for {displayName}" : "Não foi possível modificar as permissões para {displayName} ",
    "Permissions removed for {displayName}" : "Permissões removidas para {displayName} ",
    "Permissions set to default for {displayName}" : "Permissões definidas como padrão para {displayName}",
    "Phone number could not be hung up" : "Não foi possível desligar o número de telefone",
    "Phone number could not be put on hold" : "Não foi possível colocar o número de telefone em espera",
    "Phone number could not be muted" : "Não foi possível silenciar o número de telefone",
    "Phone number could not be unmuted" : "Não foi possível ativar o som do número de telefone",
    "DTMF message could not be sent" : "A mensagem DTMF não pôde ser enviada",
    "Phone number copied to clipboard" : "Número de telefone copiado para a área de transferência",
    "Phone number could not be copied" : "Não foi possível copiar o número de telefone",
    "in the lobby" : "na sala de espera",
    "Dial out phone" : "Discar telefone",
    "Hang up phone" : "Desligar telefone",
    "Move back to lobby" : "Voltar para a sala de espera",
    "Move to conversation" : "Mover para conversa",
    "Dial-in PIN" : "PIN de discagem",
    "Demote from moderator" : "Excluído da moderação",
    "Promote to moderator" : "Promover a moderador",
    "Resend invitation" : "Reenviar convite",
    "Send call notification" : "Enviar notificação de chamada",
    "Dial out phone number" : "Disque o número de telefone",
    "Resume call for phone number" : "Retomar chamada para número de telefone",
    "Put phone number on hold" : "Colocar número de telefone em espera",
    "Unmute phone number" : "Dessilenciar número de telefone",
    "Mute phone number" : "Silenciar número de telefone",
    "Copy phone number" : "Copiar número de telefone",
    "Reset custom permissions" : "Redefinir permissões personalizadas",
    "Grant all permissions" : "Conceder todas as permissões",
    "Remove all permissions" : "Remover todas as permissões",
    "Also ban from this conversation" : "Também banir desta conversa",
    "Internal note (reason to ban)" : "Nota interna (motivo para banimento)",
    "Remove" : "Remover",
    "Permissions modified for {displayName}" : "Permissões modificadas para {displayName} ",
    "Add users, groups or teams" : "Adicionar usuários, grupos ou equipes",
    "Add users or groups" : "Adicionar usuários ou grupos",
    "Add users or teams" : "Adicionar usuários ou equipes",
    "Add users" : "Adicionar usuários",
    "Add groups or teams" : "Adicionar grupos ou equipes",
    "Add groups" : "Adicionar grupos",
    "Add teams" : "Adicionar equipes",
    "Add other sources" : "Adicionar outras fontes",
    "Add emails" : "Adicionar e-mails",
    "Integrations" : "Integrações",
    "Add federated users" : "Adicionar usuários federados",
    "Searching …" : "Pesquisando...",
    "Search for more users" : "Pesquisar por mais usuários",
    "You can search or add participants via name, email, or Federated Cloud ID" : "Você pode pesquisar ou adicionar participantes por nome, e-mail ou ID de Nuvem Federada",
    "Search or add participants" : "Procure ou adicione participantes",
    "Invitation was sent to {actorId}" : "O convite foi enviado para {actorId}",
    "An error occurred while adding the participants" : "Ocorreu um erro ao adicionar os participantes",
    "A new group conversation with selected participant will be created" : "Será criada uma nova conversa de grupo com o participante selecionado",
    "Participants" : "Participantes",
    "Pinned by a deleted user" : "Fixada por um usuário excluído",
    "Participants ({count})" : "Participantes ({count}) ",
    "Open chat" : "Abrir bate-papo",
    "You have new unread messages in the chat." : "Você tem novas mensagens não lidas no bate-papo.",
    "You have been mentioned in the chat." : "Você foi mencionado no bate-papo.",
    "Search messages" : "Pesquisar mensagens",
    "Chat" : "Conversa",
    "Details" : "Detalhes",
    "Shared items" : "Itens compartilhados",
    "Search in {name}" : "Pesquisar em {name}",
    "Threads in {name}" : "Fios em {name}",
    "{actor} in {conversation}" : "{actor} em {conversation}",
    "Search messages …" : "Pesquisar mensagens …",
    "Search options" : "Opções de pesquisa",
    "From User" : "Do Usuário",
    "Since" : "Desde",
    "Until" : "Até",
    "No results found" : "Nenhum resultado encontrado",
    "Load more results" : "Carregar mais resultados ",
    "Recent threads" : "Fios recentes",
    "Projects" : "Projetos",
    "No shared items" : "Nenhum item compartilhado",
    "Thread notifications" : "Notificações de fios",
    "Thread actions" : "Ações de fios",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Link para uma conversa",
    "No open conversations found" : "Nenhuma conversa aberta encontrada",
    "Either there are no open conversations or you joined all of them." : "Ou não há conversas abertas ou você entrou em todas elas.",
    "Check spelling or use complete words." : "Verifique a ortografia ou use palavras completas.",
    "Search conversations or users" : "Pesquisar conversas ou usuários",
    "Select conversation" : "Selecionar conversa",
    "Number length is not valid" : "O comprimento do número não é válido",
    "Region code is not valid" : "O código de região não é válido",
    "Number length is too short" : "O comprimento do número é muito curto",
    "Number length is too long" : "O comprimento do número é muito longo",
    "Number is not valid" : "O número não é válido",
    "Phone numbers" : "Números de telefone",
    "Display name: {name}" : "Nome de exibição: {name}",
    "Edit display name" : "Editar nome de exibição",
    "Display name (required)" : "Nome de exibição (obrigatório)",
    "Save name" : "Salvar o nome",
    "I picked message bubbles" : "Eu escolhi balões de mensagem",
    "I picked the list style" : "Eu escolhi o estilo em lista",
    "Error while setting personal setting" : "Erro ao definir a configuração pessoal",
    "Error while saving sounds setting" : "Erro ao salvar configuração de sons ",
    "Compact conversations list" : "Lista de conversas compacta",
    "Chat appearance" : "Aparência de bate-papos",
    "Messages list" : "Lista de mensagens",
    "Message bubbles" : "Balões de mensagem",
    "Play sounds when participants join or leave a call" : "Reproduzir sons quando os participantes entram ou saem de uma chamada",
    "Currently not available on iPhone and iPad due to technical restrictions by the manufacturer" : "Atualmente indisponível no iPhone e iPad devido a restrições técnicas do fabricante",
    "Notification settings" : "Configurações de notificação",
    "Sounds for chat and call notifications" : "Sons para notificações de bate-papos e chamadas",
    "Invalid language ({languageId})" : "Idioma inválido ({languageId})",
    "Default language" : "Idioma padrão",
    "Default language ({languageName})" : "Idioma padrão ({languageName})",
    "Error when trying to load the available live translation languages" : "Erro ao tentar carregar os idiomas de tradução em tempo real disponíveis",
    "Error when trying to set live translation language" : "Erro ao tentar definir o idioma da tradução em tempo real",
    "Set language used to show the transcriptions" : "Definir o idioma usado para mostrar as transcrições",
    "Select location for attachments" : "Selecionar localização para os anexos",
    "Error while setting attachment folder" : "Erro ao definir a pasta do anexo",
    "Error while setting read status privacy" : "Ocorreu um erro ao definir a privacidade do status de leitura",
    "Error while setting typing status privacy" : "Erro ao definir a privacidade do status de digitação",
    "Error while setting default media state" : "Erro ao definir o estado de mídia padrão",
    "Turn camera and microphone off by default" : "Desativar câmera e microfone por padrão",
    "Blur camera background by default" : "Desfocar o fundo da câmera por padrão",
    "Skip device preview before joining a call" : "Pular a pré-visualização dos dispositivos antes de entrar em uma chamada",
    "Camera will be turned off when joining. Always shown if recording consent is required." : "A câmera será desligada ao entrar na chamada. Será sempre exibido se for necessário consentimento para a gravação.",
    "Appearance & Sounds" : "Aparência & Sons",
    "Privacy" : "Privacidade",
    "Send read receipts" : "Enviar confirmação de recebimento",
    "When off, all read statuses will be hidden" : "Quando desativado, todos os status de leitura serão ocultados",
    "Share typing status" : "Compartilhar status de digitação",
    "When off, all typing indicators will be hidden" : "Quando desativado, todos os indicadores de digitação serão ocultados",
    "Attachments folder" : "Pasta para os anexos",
    "Toggle full screen" : "Alternar modo de tela cheia",
    "Return to Home screen" : "Voltar à página inicial",
    "Search" : "Pesquisar",
    "Shortcuts while in a chat" : "Atalhos durante um bate-bapo",
    "Focus the chat input" : "Foco na entrada do bate-papo",
    "Unfocus the chat input to use shortcuts" : "Desfoque a entrada do bate-papo para usar atalhos",
    "Edit your last message" : "Editar sua última mensagem",
    "Shortcuts while in a call" : "Atalhos durante a chamada",
    "Camera on and off" : "Câmera ligada e desligada",
    "Microphone on and off" : "Microfone ligado e desligado",
    "Raise or lower hand" : "Levantar ou baixar a mão",
    "Push to talk or push to mute" : "Aperte para falar ou para deixar mudo",
    "Zoom-in / zoom-out a screen share" : "Aumentar / diminuir o zoom de um compartilhamento de tela",
    "Mouse wheel" : "Roda do mouse",
    "Start call silently" : "Iniciar chamada silenciosamente",
    "Start call" : "Iniciar chamada",
    "End call" : "Encerrar chamada",
    "The server was updated, you cannot start or join a call." : "O servidor foi atualizado, você não pode iniciar ou participar de uma chamada.",
    "This call has just ended" : "Esta chamada acabou de terminar",
    "You will be able to join the call only after a moderator starts it." : "Você só poderá entrar na chamada depois que um moderador a iniciar.",
    "End call for everyone" : "Encerrar chamada para todos",
    "Starting the recording" : "Iniciando a gravação",
    "Recording" : "Gravação",
    "The call has been running for one hour." : "A chamada está em andamento há uma hora.",
    "Cancel recording start" : "Cancelar início da gravação",
    "Stop recording" : "Encerrar gravação",
    "Send a reaction" : "Enviar reação",
    "React with {reaction}" : "Reagir com {reaction}",
    "All tasks done!" : "Todas as tarefas concluídas!",
    "_{done} of %n task_::_{done} of %n tasks_" : ["{done} de %n tarefa","{done} de %n tarefas","{done} de %n tarefas"],
    "Add participants to this call" : "Adicionar participantes a esta chamada",
    "_%n participant in call_::_%n participants in call_" : ["%n participante na chamada","%n participantes na chamada","%n participantes na chamada"],
    "Scheduled messages" : "Mensagens agendadas",
    "You are not allowed to enable screensharing" : "Você não tem permissão para ativar o compartilhamento de tela",
    "No screensharing" : "Sem compartilhamento de tela",
    "Screensharing options" : "Opções de compartilhamento de tela",
    "Enable screensharing" : "Ativar compartilhamento de tela",
    "Bad sent video and screen quality." : "Má qualidade de vídeo e tela enviados.",
    "Bad sent screen quality." : "Má qualidade da tela enviada.",
    "Bad sent video quality." : "Má qualidade de vídeo enviada.",
    "Bad sent audio, video and screen quality." : "Má qualidade de áudio, vídeo e tela enviados.",
    "Bad sent audio and screen quality." : "Má qualidade de áudio e tela enviados.",
    "Bad sent audio and video quality." : "Má qualidade de áudio e vídeo enviados.",
    "Bad sent audio quality." : "Má qualidade de áudio enviada.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Sua conexão com a Internet ou computador estão ocupados e outros participantes talvez não consigam ver sua tela. Para melhorar a situação, tente desativar o desfoque do plano de fundo ou seu vídeo ao fazer um compartilhamento de tela.",
    "Disable background blur" : "Desativar o desfoque do plano de fundo",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Sua conexão com a Internet ou computador estão ocupados e outros participantes talvez não consigam ver sua tela. Para melhorar a situação, tente desativar seu vídeo ao fazer um compartilhamento de tela.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Sua conexão à internet ou o computador estão ocupados e outros participantes talvez não consigam ver sua tela.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Sua conexão à internet ou o computador estão ocupados e outros participantes talvez não consigam ver você.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "Sua conexão com a Internet ou computador estão ocupados e outros participantes talvez não consigam entender e ver você. Para melhorar a situação, tente desativar o desfoque do plano de fundo ou seu vídeo ao fazer um compartilhamento de tela. ",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Sua conexão à internet ou o computador estão ocupados e outros participantes talvez não consigam ver e entender você. Para melhorar a situação, tente desativar seu vídeo ao fazer um compartilhamento de tela.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "Sua conexão com a Internet ou computador estão ocupados e outros participantes talvez não consigam entender você e ver sua tela. Para melhorar a situação, tente desativar o compartilhamento de tela. ",
    "Disable screenshare" : "Desativar compartilhamento de tela",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "Sua conexão com a Internet ou computador estão ocupados e outros participantes talvez não consigam entender e ver você. Para melhorar a situação, tente desativar o desfoque do plano de fundo ou seu vídeo. ",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Sua conexão à internet ou o computador estão ocupados e outros participantes talvez não consigam ver e entender você. Para melhorar a situação, tente desativar seu vídeo.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Sua conexão à internet ou o computador estão ocupados e outros participantes talvez não consigam entender você.",
    "Screen sharing is not supported by your browser." : "O compartilhamento de tela não é suportado pelo seu navegador.",
    "Screen sharing requires the page to be loaded through HTTPS." : "O compartilhamento de tela exige que a página seja carregada por HTTPS.",
    "Screensharing requires the page to be loaded through HTTPS." : "O compartilhamento de tela requer que a página seja carregada através de HTTPS.",
    "An error occurred while starting screensharing." : "Ocorreu um erro ao iniciar o compartilhamento de tela.",
    "Select virtual background" : "Selecionar fundo virtual",
    "Show your screen" : "Exibir sua tela",
    "Stop screensharing" : "Encerrar compartilhamento da tela",
    "Mute others" : "Silenciar outros",
    "Start recording" : "Iniciar gravação",
    "Set up breakout rooms" : "Criar salas temáticas",
    "Download attendance list" : "Baixar a lista de presença",
    "Open Calendar" : "Abrir Calendário",
    "Remove participant {name}" : "Remover participante {name}",
    "Would you like to delete this conversation?" : "Você gostaria de excluir esta conversa?",
    "_This conversation will be automatically deleted for everyone after %n day of inactivity._::_This conversation will be automatically deleted for everyone after %n days of inactivity._" : ["Esta conversa será automaticamente excluída para todos após %n dia de inatividade.","Esta conversa será automaticamente excluída para todos após %n de dias de inatividade.","Esta conversa será automaticamente excluída para todos após %n dias de inatividade."],
    "Are you sure you want to delete this conversation?" : "Tem certeza de que deseja excluir esta conversa?",
    "Delete now" : "Excluir agora",
    "Keep" : "Manter",
    "Open dialpad" : "Abrir teclado de discagem",
    "Select a region" : "Selecionar uma região",
    "Local time: {time}" : "Horário local: {time}",
    "Scheduled {datetime}" : "Agendado {datetime}",
    "Scheduled for {datetime}" : "Agendado para {datetime}",
    "Search …" : "Pesquisar …",
    "Message without mention" : "Mensagem sem menção",
    "Mention myself" : "Mencionar-me",
    "Mention everyone" : "Mencionar todo mundo",
    "Select a conversation" : "Selecionar uma conversa",
    "Select a mode" : "Selecionar um modo",
    "You do not have permissions to access this conversation." : "Você não tem permissões para acessar esta conversa.",
    "Join a different conversation or start a new one." : "Entre em uma conversa diferente ou inicie uma nova.",
    "The conversation does not exist" : "A conversa não existe",
    "Join a conversation or start a new one!" : "Juntar-se à uma conversa ou iniciar um nova!",
    "Duplicate session" : "Sessão duplicada",
    "This conversation was opened in another tab. The current server version does not support opening a conversation in multiple tabs." : "Esta conversa foi aberta em outra aba. A versão atual do servidor não suporta a abertura de uma conversa em várias abas.",
    "Creating and joining a conversation with \"{userid}\"" : "Criando e entrando em uma conversa com \"{userid}\"",
    "Join a conversation or start a new one" : "Entre em uma conversa ou inicie outra",
    "Error while joining the conversation" : "Erro ao entrar na conversa",
    "Another user" : "Outro usuário",
    "Hey! Are you using the list style or message bubbles?" : "Ei! Você está usando o estilo em lista ou balões de mensagem?",
    "Nextcloud URL" : "URL Nextcloud",
    "Nextcloud user" : "Usuário Nextcloud",
    "User password" : "Senha do usuário",
    "Talk conversation" : "Conversa Talk",
    "Skip TLS verification" : "Ignorar verificação TLS",
    "Matrix server URL" : "URL do servidor Matrix",
    "User" : "Usuário",
    "Matrix channel" : "Canal Matrix",
    "Mattermost server URL" : "URL do servidor Mattermost",
    "Mattermost user" : "Usuário Mattermost",
    "Team name" : "Nome do team",
    "Channel name" : "Nome do canal",
    "Rocket.Chat server URL" : "URL do servidor Rocket.Chat",
    "User name or email address" : "Nome de usuário ou endereço de e-mail ",
    "Rocket.Chat channel" : "Canal Rocket.Chat",
    "Zulip server URL" : "URL do servidor Zulip",
    "Bot user name" : "Nome do usuário Bot",
    "Bot API key" : "Chave API do BOT",
    "Zulip channel" : "Canal Zulip",
    "API token" : "Token de API",
    "Slack channel" : "Canal Slack",
    "Server ID or name" : "Nome ou ID do servidor",
    "Channel ID (prefixed with \"ID:\") or name" : "ID do canal (prefixado com \"ID:\") ou nome",
    "Channel" : "Canal",
    "Login" : "Login",
    "Chat ID" : "ID do Chat",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "URL do servidor IRC (por ex. chat.freenode.net:6667)",
    "Nickname" : "Apelido",
    "Connection password" : "Senha de conexão",
    "IRC channel" : "Canal IRC",
    "Channel password" : "Senha do canal",
    "NickServ nickname" : "Apelido do NickServ",
    "NickServ password" : "Senha do NickServ",
    "Use TLS" : "Usar TLS",
    "Use SASL" : "Usar SASL",
    "Tenant ID" : "ID do Tenant",
    "Client ID" : "ID do cliente",
    "Team ID" : "ID do Team",
    "Thread ID" : "ID da Thread",
    "XMPP/Jabber server URL" : "URL do servidor XMPP/Jabber",
    "MUC server URL" : "URL do servidor MUC",
    "Jabber ID" : "ID Jabber",
    "Pinned messages" : "Mensagem fixada",
    "Media" : "Mídia",
    "Polls" : "Enquetes",
    "Deck cards" : "Cartões de Deck",
    "Voice messages" : "Mensagens de voz",
    "Locations" : "Localizações",
    "Call recordings" : "Gravações de chamadas",
    "Audio" : "Áudio",
    "Show all pinned messages" : "Mostrar todas as mensagens fixadas",
    "Show all media" : "Mostrar todas as mídias",
    "Show all files" : "Mostrar todos os arquivos",
    "Show all polls" : "Mostrar todas as enquetes",
    "Show all deck cards" : "Mostrar todos os cartões de Deck",
    "Show all voice messages" : "Mostrar todas as mensagens de voz",
    "Show all locations" : "Mostrar todas as localizações",
    "Show all call recordings" : "Mostrar todas as gravações",
    "Show all audio" : "Mostrar todos o áudios",
    "Show all other" : "Mostrar todos os outros",
    "Follow conversation settings" : "Seguir as configurações da conversa",
    "Group" : "Grupo",
    "Team" : "Equipe",
    "You reconnected to the call" : "Você se reconectou à chamada",
    "{actor} reconnected to the call" : "{actor} se reconectou à chamada",
    "You added {user0} and {user1}" : "Você adicionou {user0} e {user1}",
    "_You added {user0}, {user1} and %n more participant_::_You added {user0}, {user1} and %n more participants_" : ["Você adicionou {user0}, {user1} e mais %n participante","Você adicionou {user0}, {user1} e mais %n participantes","Você adicionou {user0}, {user1} e mais %n participantes"],
    "An administrator added you and {user0}" : "Um administrador adicionou você e {user0}",
    "{actor} added you and {user0}" : "{actor} adicionou você e {user0}",
    "_An administrator added you, {user0} and %n more participant_::_An administrator added you, {user0} and %n more participants_" : ["Um administrador adicionou você, {user0} e mais %n participante","Um administrador adicionou você, {user0} e mais %n participantes","Um administrador adicionou você, {user0} e mais %n participantes"],
    "_{actor} added you, {user0} and %n more participant_::_{actor} added you, {user0} and %n more participants_" : ["{actor} adicionou você, {user0} e mais %n participante","{actor} adicionou você, {user0} e mais %n participantes","{actor} adicionou você, {user0} e mais %n participantes"],
    "An administrator added {user0} and {user1}" : "Um administrador adicionou {user0} e {user1}",
    "{actor} added {user0} and {user1}" : "{actor} adicionou {user0} e {user1}",
    "_An administrator added {user0}, {user1} and %n more participant_::_An administrator added {user0}, {user1} and %n more participants_" : ["Um administrador adicionou {user0}, {user1} e mais %n participante","Um administrador adicionou {user0}, {user1} e mais %n participantes","Um administrador adicionou {user0}, {user1} e mais %n participantes"],
    "_{actor} added {user0}, {user1} and %n more participant_::_{actor} added {user0}, {user1} and %n more participants_" : ["{actor} adicionou {user0}, {user1} e mais %n participante","{actor} adicionou {user0}, {user1} e mais %n participantes","{actor} adicionou {user0}, {user1} e mais %n participantes"],
    "You removed {user0} and {user1}" : "Você removeu {user0} e {user1}",
    "_You removed {user0}, {user1} and %n more participant_::_You removed {user0}, {user1} and %n more participants_" : ["Você removeu {user0}, {user1} e mais %n participante","Você removeu {user0}, {user1} e mais %n participantes","Você removeu {user0}, {user1} e mais %n participantes"],
    "An administrator removed you and {user0}" : "Um administrador removeu você e {user0}",
    "{actor} removed you and {user0}" : "{actor} removeu você e {user0}",
    "_An administrator removed you, {user0} and %n more participant_::_An administrator removed you, {user0} and %n more participants_" : ["Um administrador removeu você, {user0} e mais %n participante","Um administrador removeu você, {user0} e mais %n participantes","Um administrador removeu você, {user0} e mais %n participantes"],
    "_{actor} removed you, {user0} and %n more participant_::_{actor} removed you, {user0} and %n more participants_" : ["{actor} removeu você, {user0} e mais %n participante","{actor} removeu você, {user0} e mais %n participantes","{actor} removeu você, {user0} e mais %n participantes"],
    "An administrator removed {user0} and {user1}" : "Um administrador removeu {user0} e {user1}",
    "{actor} removed {user0} and {user1}" : "{actor} removeu {user0} e {user1}",
    "_An administrator removed {user0}, {user1} and %n more participant_::_An administrator removed {user0}, {user1} and %n more participants_" : ["Um administrador removeu {user0}, {user1} e mais %n participante","Um administrador removeu {user0}, {user1} e mais %n participantes","Um administrador removeu {user0}, {user1} e mais %n participantes"],
    "_{actor} removed {user0}, {user1} and %n more participant_::_{actor} removed {user0}, {user1} and %n more participants_" : ["{actor} removeu {user0}, {user1} e mais %n participante","{actor} removeu {user0}, {user1} e mais %n participantes","{actor} removeu {user0}, {user1} e mais %n participantes"],
    "You and {user0} joined the call" : "Você e {user0} entraram na chamada",
    "_You, {user0} and %n more participant joined the call_::_You, {user0} and %n more participants joined the call_" : ["Você, {user0} e mais %n participante entraram na chamada","Você, {user0} e mais %n participantes entraram na chamada","Você, {user0} e mais %n participantes entraram na chamada"],
    "{user0} and {user1} joined the call" : "{user0} e {user1} entraram na chamada",
    "_{user0}, {user1} and %n more participant joined the call_::_{user0}, {user1} and %n more participants joined the call_" : ["{user0}, {user1} e mais %n participante entraram na chamada","{user0}, {user1} e mais %n participantes entraram na chamada","{user0}, {user1} e mais %n participantes entraram na chamada"],
    "You and {user0} left the call" : "Você e {user0} saíram da chamada",
    "_You, {user0} and %n more participant left the call_::_You, {user0} and %n more participants left the call_" : ["Você, {user0} e mais %n participante saíram a chamada","Você, {user0} e mais %n participantes saíram a chamada","Você, {user0} e mais %n participantes saíram a chamada"],
    "{user0} and {user1} left the call" : "{user0} e {user1} saíram a chamada",
    "_{user0}, {user1} and %n more participant left the call_::_{user0}, {user1} and %n more participants left the call_" : ["{user0}, {user1} e mais %n participante saíram a chamada","{user0}, {user1} e mais %n participantes saíram a chamada","{user0}, {user1} e mais %n participantes saíram a chamada"],
    "You promoted {user0} and {user1} to moderators" : "Você promoveu {user0} e {user1} a moderadores",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["Você promoveu {user0}, {user1} e mais %n participante a moderadores","Você promoveu {user0}, {user1} e mais %n participantes a moderadores","Você promoveu {user0}, {user1} e mais %n participantes a moderadores"],
    "An administrator promoted you and {user0} to moderators" : "Um administrador promoveu você e {user0} a moderadores",
    "{actor} promoted you and {user0} to moderators" : "{actor} promoveu você e {user0} a moderadores",
    "_An administrator promoted you, {user0} and %n more participant to moderators_::_An administrator promoted you, {user0} and %n more participants to moderators_" : ["Um administrador promoveu você, {user0} e mais %n participante a moderadores","Um administrador promoveu você, {user0} e mais %n participantes a moderadores","Um administrador promoveu você, {user0} e mais %n participantes a moderadores"],
    "_{actor} promoted you, {user0} and %n more participant to moderators_::_{actor} promoted you, {user0} and %n more participants to moderators_" : ["{actor} promoveu você, {user0} e mais %n participante a moderadores","{actor} promoveu você, {user0} e mais %n participantes a moderadores","{actor} promoveu você, {user0} e mais %n participantes a moderadores"],
    "An administrator promoted {user0} and {user1} to moderators" : "Um administrador promoveu {user0} e {user1} a moderadores",
    "{actor} promoted {user0} and {user1} to moderators" : "{actor} promoveu {user0} e {user1} a moderadores",
    "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["Um administrador promoveu {user0}, {user1} e mais %n participante a moderadores","Um administrador promoveu {user0}, {user1} e mais %n participantes a moderadores","Um administrador promoveu {user0}, {user1} e mais %n participantes a moderadores"],
    "_{actor} promoted {user0}, {user1} and %n more participant to moderators_::_{actor} promoted {user0}, {user1} and %n more participants to moderators_" : ["{actor} promoveu {user0}, {user1} e mais %n participante a moderadores","{actor} promoveu {user0}, {user1} e mais %n participantes a moderadores","{actor} promoveu {user0}, {user1} e mais %n participantes a moderadores"],
    "You demoted {user0} and {user1} from moderators" : "Você rebaixou {user0} e {user1} de moderadores",
    "_You demoted {user0}, {user1} and %n more participant from moderators_::_You demoted {user0}, {user1} and %n more participants from moderators_" : ["Você rebaixou {user0}, {user1} e mais %n participante de moderadores","Você rebaixou {user0}, {user1} e mais %n participantes de moderadores","Você rebaixou {user0}, {user1} e mais %n participantes de moderadores"],
    "An administrator demoted you and {user0} from moderators" : "Um administrador rebaixou você e {user0} de moderadores",
    "{actor} demoted you and {user0} from moderators" : "{actor} rebaixou você e {user0} de moderadores",
    "_An administrator demoted you, {user0} and %n more participant from moderators_::_An administrator demoted you, {user0} and %n more participants from moderators_" : ["Um administrador rebaixou você, {user0} e mais %n participante de moderadores","Um administrador rebaixou você, {user0} e mais %n participantes de moderadores","Um administrador rebaixou você, {user0} e mais %n participantes de moderadores"],
    "_{actor} demoted you, {user0} and %n more participant from moderators_::_{actor} demoted you, {user0} and %n more participants from moderators_" : ["{actor} rebaixou você, {user0} e mais %n participante de moderadores","{actor} rebaixou você, {user0} e mais %n participantes de moderadores","{actor} rebaixou você, {user0} e mais %n participantes de moderadores"],
    "An administrator demoted {user0} and {user1} from moderators" : "Um administrador rebaixou {user0} e {user1} de moderadores",
    "{actor} demoted {user0} and {user1} from moderators" : "{actor} rebaixou {user0} e {user1} de moderadores",
    "_An administrator demoted {user0}, {user1} and %n more participant from moderators_::_An administrator demoted {user0}, {user1} and %n more participants from moderators_" : ["Um administrador rebaixou {user0}, {user1} e mais %n participante de moderadores","Um administrador rebaixou {user0}, {user1} e mais %n participantes de moderadores","Um administrador rebaixou {user0}, {user1} e mais %n participantes de moderadores"],
    "_{actor} demoted {user0}, {user1} and %n more participant from moderators_::_{actor} demoted {user0}, {user1} and %n more participants from moderators_" : ["{actor} rebaixou {user0}, {user1} e mais %n participante de moderadores","{actor} rebaixou {user0}, {user1} e mais %n participantes de moderadores","{actor} rebaixou {user0}, {user1} e mais %n participantes de moderadores"],
    "You:" : "Você:",
    "You: {lastMessage}" : "Você: {lastMessage}",
    "{actor}:" : "{actor}:",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "The server was updated." : "O servidor foi atualizado.",
    "(edited by you)" : "(editado por você)",
    "(edited by a deleted user)" : "(editado por um usuário excluído)",
    "(edited by {moderator})" : "(editado por {moderator})",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Você está tentando ingressar em uma conversa enquanto realiza uma sessão ativa em outra janela ou dispositivo. No momento, isso não é suportado pelo Nextcloud Talk. O que você deseja fazer?",
    "Leave this page" : "Sair desta página",
    "Join here" : "Ingressar aqui",
    "Deck card has been posted to {conversation}" : "O cartão do Deck foi postada em {conversation}",
    "An error occurred while posting deck card to conversation" : "Ocorreu um erro ao postar o cartão do Deck na conversa",
    "Post to a conversation" : "Postar em uma conversa",
    "Post to conversation" : "Postar na conversa",
    "The recording failed. Please contact your administrator." : "A gravação falhou. Por favor, contate seu administrador.",
    "Location has been posted to {conversation}" : "O localização foi postado em {conversation}",
    "An error occurred while posting location to conversation" : "Ocorreu um erro ao postar a localização na conversa",
    "Share to a conversation" : "Compartilhar em uma conversa",
    "Share to conversation" : "Compartilhar na conversa",
    "In conversation" : "Em conversação",
    "Search in conversation: {conversation}" : "Pesquisar na conversa: {conversation}",
    "Your requests are throttled at the moment due to brute force protection" : "Suas solicitações estão limitadas no momento devido à proteção contra força bruta",
    "Error while clearing conversation history" : "Erro ao limpar o histórico da conversa ",
    "Error occurred while allowing guests" : "Erro ocorrido ao permitir convidados",
    "Error occurred while disallowing guests" : "Erro ocorrido ao não permitir convidados",
    "Error occurred when restricting the conversation to moderator" : "Ocorreu um erro ao restringir a conversa ao moderador",
    "Error occurred when opening the conversation to everyone" : "Ocorreu um erro ao abrir a conversa para todos",
    "Conversation password has been saved" : "A senha da conversa foi salva",
    "Conversation password has been removed" : "A senha da conversa foi removida",
    "Error occurred while saving conversation password" : "Ocorreu um erro ao salvar a senha da conversa",
    "Call recording is starting." : "Iniciando gravação da chamada.",
    "Call recording stopped while starting." : "A gravação da chamada foi interrompida ao iniciar.",
    "Call recording stopped. You will be notified once the recording is available." : "A gravação da chamada foi interrompida. Você será notificado assim que a gravação estiver disponível.",
    "Conversation picture set" : "Imagem da conversa definida",
    "Conversation picture deleted" : "Imagem da conversa excluída",
    "Could not delete the conversation picture" : "Não foi possível excluir a imagem da conversa",
    "Could not remove the automatic expiration" : "Não foi possível remover a expiração automática",
    "Could not post message: {errorMessage}" : "Não foi possível postar a mensagem: {errorMessage}",
    "Participant is banned successfully" : "Participante está banido com sucesso",
    "Error while banning the participant" : "Erro ao banir o participante",
    "An error occurred while fetching the participants" : "Erro ao buscar os participantes",
    "Could not send invitation to {actorId}" : "Não foi possível enviar o convite para {actorId}",
    "Invitations sent" : "Convites enviados",
    "Error occurred when sending invitations" : "Ocorreu um erro ao enviar convites",
    "Failed to join the conversation." : "Falha ao entrar na conversa.",
    "An error occurred while creating breakout rooms" : "Ocorreu um erro ao criar salas temáticas",
    "An error occurred while re-ordering the attendees" : "Ocorreu um erro ao reordenar os participantes",
    "An error occurred while deleting breakout rooms" : "Ocorreu um erro ao excluir salas temáticas",
    "An error occurred while starting breakout rooms" : "Ocorreu um erro ao iniciar salas temáticas",
    "An error occurred while stopping breakout rooms" : "Ocorreu um erro ao interromper salas temáticas",
    "An error occurred while sending a message to the breakout rooms" : "Ocorreu um erro ao enviar uma mensagem para as salas temáticas",
    "An error occurred while requesting assistance" : "Ocorreu um erro ao solicitar assistência",
    "An error occurred while resetting the request for assistance" : "Ocorreu um erro ao redefinir o pedido de assistência",
    "An error occurred while joining breakout room" : "Ocorreu um erro ao entrar na sala temática",
    "Failed to rename the thread" : "Falha ao renomear o fio",
    "Error fetching upcoming events" : "Erro ao buscar próximos eventos",
    "Error fetching upcoming reminders" : "Erro ao buscar próximos lembretes",
    "An error occurred while accepting an invitation" : "Ocorreu um erro ao aceitar um convite",
    "An error occurred while rejecting an invitation" : "Ocorreu um erro ao rejeitar um convite",
    "{guest} (guest)" : "{guest} (convidado)",
    "Poll draft has been saved" : "O rascunho da enquete foi salva",
    "An error occurred while saving the draft" : "Ocorreu um erro ao salvar o rascunho",
    "An error occurred while submitting your vote" : "Um erro ocorreu ao enviar seu voto",
    "An error occurred while ending the poll" : "Ocorreu um erro ao encerrar a enquete",
    "An error occurred while deleting the poll draft" : "Ocorreu um erro ao excluir o rascunho da enquete",
    "Poll \"{name}\" was created by {user}. Click to vote" : "A enquete \"{name}\" foi criada por {user}. Clique para votar",
    "Failed to add reaction" : "Falha ao adicionar reação",
    "Failed to remove reaction" : "Falha ao remover reação",
    "The server is in maintenance mode." : "O servidor está em modo de manutenção.",
    "Federated server was updated." : "O servidor federado foi atualizado.",
    "Error while uploading file \"{fileName}\"" : "Erro ao enviar o arquivo \"{fileName}\"",
    "Not enough free space to upload file \"{fileName}\"" : "Espaço livre insuficiente para enviar o arquivo \"{fileName}\"",
    "You are not allowed to share files" : "Você não tem permissão para compartilhar arquivos",
    "Error while sharing file" : "Erro ao compartilhar arquivo",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "O navegador que você está usando não possui suporte completo pelo Nextcloud Talk. Use a última versão do Mozilla Firefox, Microsoft Edge, Google Chrome, Opera ou Apple Safari.",
    "_In %n hour_::_In %n hours_" : ["Em %n hora","Em %n horas","Em %n horas"],
    "_%n minute _::_%n minutes_" : ["%n minuto","%n minutos","%n minutos"],
    "In {hours} and {minutes}" : "Em {hours} e {minutes}",
    "_In %n minute_::_In %n minutes_" : ["Em %n minuto","Em %n minutos","Em %n minutos"],
    "Later today – {timeLocale}" : "Hoje mais tarde – {timeLocale}",
    "Set time for later today" : "Definir um horário para mais tarde hoje",
    "Tomorrow – {timeLocale}" : "Amanhã – {timeLocale}",
    "Set time for tomorrow" : "Definir um horário para amanhã",
    "This weekend – {timeLocale}" : "Este fim de semana – {timeLocale}",
    "Set time for this weekend" : "Definir um horário para este fim de semana",
    "Next week – {timeLocale}" : "Próxima semana – {timeLocale}",
    "Set time for next week" : "Definir um horário para a semana que vem",
    "Message link copied to clipboard" : "Link da mensagem copiado para a área de transferência",
    "Conversation link copied to clipboard" : "Link da conversa copiado para a área de transferência",
    "The link could not be copied" : "O link não pôde ser copiado",
    "Error while parsing a PROPFIND error" : "Erro ao analisar um erro PROPFIND",
    "Sending signaling message has failed" : "Erro no envio da mensagem de sinalização",
    "Lost connection to signaling server. Trying to reconnect." : "Conexão perdida com o servidor de sinalização. Tentando reconectar.",
    "Lost connection to signaling server." : "Perda de conexão com o servidor de sinalização.",
    "Connecting is taking longer than expected …" : "A conexão está demorando mais do que o esperado …",
    "Failed to connect. Retrying …" : "Falha na conexão. Tentando novamente …",
    "Failed to connect. The signaling server may be set up incorrectly" : "Falha na conexão. O servidor de sinalização pode estar configurado incorretamente",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "O servidor de sinalização configurado precisa ser atualizado para ser compatível com esta versão do Talk. Entre em contato com o seu administrador.",
    "Please restart the app." : "Por favor, reinicie o aplicativo.",
    "Please reload the page." : "Por favor, recarregue a página",
    "Please try to restart the app." : "Por favor, tente reiniciar o aplicativo.",
    "Please try to reload the page." : "Por favor, tente recarregar a página.",
    "Do not disturb" : "Não perturbe",
    "Away" : "Fora",
    "Microphone {number}" : "Microfone {number}",
    "Camera {number}" : "Câmera {number}",
    "Speaker {number}" : "Alto falante {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Parece que você está falando no \"mudo\". Ligue o microfone para outros ouvirem",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Não foi possível estabelecer uma conexão com pelo menos um participante. Pode ser necessário um servidor TURN para sua instalação. Peça ao seu administrador para configurar um seguindo {linkstart}esta documentação{linkend}.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Isso está demorando mais que o esperado. As permissões de mídia já foram concedidas (ou rejeitadas)? Se sim, reinicie o seu navegador, pois o áudio e vídeo estão falhando",
    "Access to microphone & camera is only possible with HTTPS" : "O acesso ao microfone e à câmera só é possível com HTTPS",
    "Please move your setup to HTTPS" : "Altere sua configuração para HTTPS",
    "Access to microphone & camera was denied" : "O acesso ao microfone e à câmera foi negado",
    "WebRTC is not supported in your browser" : "WebRTC não é suportado pelo seu navegador",
    "Please use a different browser like Firefox or Chrome" : "Utilize um navegador diferente como o Firefox ou Chrome",
    "Error while accessing microphone & camera" : "Erro ao acessar microfone & câmera",
    "%s Talk on your mobile devices" : "%s Converse em seus dispositivos móveis",
    "Join conversations at any time, anywhere, on any device." : "Participe de conversas a qualquer momento, lugar e dispositivo.",
    "Android app" : "Aplicativo Android",
    "iOS app" : "Aplicativo iOS",
    "__language_name__" : "Português Brasileiro",
    "Webhook Demo" : "Demonstração de Webhook",
    "Call summary (%s)" : "Resumo da chamada (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "O bot de resumo da chamada posta uma mensagem de visão geral após a chamada, listando todos os participantes e descrevendo as tarefas",
    "Tasks" : "Tarefas",
    "Notes" : "Notas ",
    "Reports" : "Relatórios",
    "Decisions" : "Decisões",
    "Agenda" : "Agenda",
    "Call summary" : "Resumo da chamada",
    "Call summary - {title}" : "Resumo da chamada - {title}",
    "Talk conversation for event" : "Conversa do Talk para evento",
    "Client Push is installed, this improves the performance of desktop clients." : "O Client Push está instalado, o que melhora o desempenho dos clientes de desktop.",
    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "O {notify_push} não está instalado, o que pode levar a problemas de desempenho ao usar clientes de desktop.",
    "Next meeting" : "Próxima reunião",
    "Schedule a meeting from your calendar. A Talk conversation needs to be set as location to show up here" : "Agende uma reunião a partir do seu calendário. Uma conversa no Talk precisa ser definida como local para aparecer aqui.",
    "Join conversations from remote Nextcloud servers" : "Entre em conversas de servidores Nextcloud remotos",
    "Your default media state has been saved" : "Seu estado de mídia padrão foi salvo",
    "Set reminder for later today" : "Definir lembrete para hoje mais tarde",
    "Set reminder for tomorrow" : "Definir lembrete para amanhã",
    "Set reminder for this weekend" : "Definir lembrete para este fim de semana",
    "Set reminder for next week" : "Definir lembrete para a próxima semana",
    "Generate summary" : "Gerar resumo",
    "Open poll • You voted already" : "Enquete aberta • Você já votou",
    "Open poll • Click to vote" : "Enquete aberta • Clique para votar",
    "Poll • Ended" : "Enquete • Encerrada",
    "Talk recording from {time} ({conversation})" : "Gravação do Talk de {time} ({conversation})",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["Resultado da enquete • %n voto","Resultado da enquete • %n votos","Resultado da enquete • %n votos"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["Enquete aberta • %n voto","Enquete aberta • %n votos","Enquete aberta • %n votos"],
    "Submit vote" : "Enviar voto",
    "Your privacy setting has been saved" : "Sua configuração de privacidade foi salva",
    "Your personal setting has been saved" : "Sua configuração pessoal foi salva",
    "Failed to save sounds setting" : "Falha ao salvar configuração de sons",
    "Sounds setting saved" : "Configuração de sons salva ",
    "Always shown if recording consent is required" : "Sempre exibido se for necessário consentimento para gravação",
    "Nextcloud Talk was updated, you cannot start or join a call." : "O Nextcloud Talk foi atualizado, você não pode iniciar ou entrar em uma chamada.",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Você ingressou na conversa em outra janela ou dispositivo. No momento, isso não é suportado pelo Nextcloud Talk e portanto esta sessão foi encerrada.",
    "Nextcloud Talk was updated." : "O Nextcloud Talk foi atualizado.",
    "Nextcloud is in maintenance mode." : "O Nextcloud está em modo de manutenção.",
    "Nextcloud Talk Federation was updated." : "O Nextcloud Talk Federation foi atualizado.",
    "Enable live translation" : "Ativar tradução em tempo real",
    "I picked list style" : "Eu escolhi o estilo lista",
    "Hey! Are you using Talk in list style or with message bubbles?" : "Ei! Você está usando o Talk no estilo lista ou com balões de mensagem?"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
